@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-25 01:05:39 jcs>
+/* Time-stamp: <2005-12-14 23:12:43 jcs>
 |
 |  Copyright (C) 2003 Corey Donohoe <atmos at atmos dot org>
 |  Copyright (C) 2003-2005 Jorg Schuler <jcsjcs at users sourceforge net>
@@ -25,20 +25,24 @@
 | 
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: context_menus.c,v 1.42 2005/06/24 16:17:18 jcsjcs Exp $
+|  $Id: context_menus.c,v 1.52 2005/12/11 08:52:30 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
+#include "itdb.h"
+#include "details.h"
 #include "display.h"
 #include "file.h"
 #include "misc.h"
 #include "misc_track.h"
 #include "prefs.h"
 #include "tools.h"
-#include "itdb.h"
+#include "podcast.h"
+
+#define LOCALDEBUG 1
 
 static guint entry_inst = -1;
 static GList *selected_tracks = NULL;
@@ -54,10 +58,50 @@ typedef enum {
 } CM_type;
 
 
+#if LOCALDEBUG
+/**
+ * do_special - for debugging: change as needed to obtain information
+ * on selected tracks
+ * @mi - the menu item selected
+ * @data - ignored, should be NULL
+ */
+static void 
+do_special(GtkWidget *w, gpointer data)
+{
+    GList *gl;
+
+    for (gl=selected_tracks; gl; gl=gl->next)
+    {
+	gchar *mp;
+	Track *tr = gl->data;
+	g_return_if_fail (tr);
+
+	g_object_get (tr->itdb->device, "mount-point", &mp, NULL);
+	printf ("mountpoint: %s\n", mp);
+	g_free (mp);
+
+	printf ("track: %p: thumbnails: %p id: %d num: %d\n",
+		tr, tr->artwork->thumbnails, tr->artwork->id, g_list_length (tr->artwork->thumbnails));
+	if (tr->artwork->thumbnails)
+	{
+	    GList *gl2;
+	    for (gl2=tr->artwork->thumbnails; gl2; gl2=gl2->next)
+	    {
+		Thumb *img = gl2->data;
+		g_return_if_fail (img);
+		printf ("  %s offset: %d size: %d width: %d height: %d\n", img->filename, img->offset, img->size, img->width, img->height);
+	    }
+	}
+    }
+}
+#endif
+
+
+
 /**
  * export_entries - export the currently selected files to disk
  * @mi - the menu item selected
- * @data - ignored, shoould be NULL
+ * @data - ignored, should be NULL
  */
 static void 
 export_entries(GtkWidget *w, gpointer data)
@@ -70,7 +114,7 @@ export_entries(GtkWidget *w, gpointer data)
  * create_playlist_file - write a playlist file containing the
  * currently selected tracks.
  * @mi - the menu item selected
- * @data - ignored, shoould be NULL
+ * @data - ignored, should be NULL
  */
 static void 
 create_playlist_file(GtkWidget *w, gpointer data)
@@ -118,6 +162,22 @@ play_entries_enqueue (GtkMenuItem *mi, gpointer data)
 }
 
 
+/*
+ * show_details_entries - show details of tracks currently selected
+ * @mi - the menu item selected
+ * @data - Ignored, should be NULL
+ */
+static void 
+edit_details_entries(GtkMenuItem *mi, gpointer data)
+{
+    if (selected_playlist)
+	details_edit (selected_playlist->members);
+    else if(selected_entry)
+	details_edit (selected_entry->members);
+    else if(selected_tracks)
+	details_edit (selected_tracks);
+}
+
 /*
  * update_entries - update the entries currently selected
  * @mi - the menu item selected
@@ -158,8 +218,10 @@ sync_dirs_entries(GtkMenuItem *mi, gpointer data)
  * @data - ignored, should be NULL
  */
 static void 
-delete_entries(GtkMenuItem *mi, DeleteAction deleteaction)
+delete_entries(GtkMenuItem *mi, gpointer data)
 {
+    DeleteAction deleteaction = GPOINTER_TO_INT (data);
+
     if (selected_playlist)
 	delete_playlist_head (deleteaction);
     else if(selected_entry)
@@ -279,16 +341,23 @@ create_context_menu(CM_type type)
 {
     static GtkWidget *menu[CM_NUM];
     static GtkWidget *mi_exp[CM_NUM];  /* Export Tracks */
-    static GtkWidget *mi_pl[CM_NUM];   /* DELETE_ACTION_PLAYLIST */
-    static GtkWidget *mi_ipod[CM_NUM]; /* DELETE_ACTION_IPOD     */
-    static GtkWidget *mi_local[CM_NUM];/* DELETE_ACTION_LOCAL    */
-    static GtkWidget *mi_db[CM_NUM];   /* DELETE_ACTION_DATABASE */
-    static GtkWidget *mi_sep[CM_NUM];  /* separator              */
+    static GtkWidget *mi_delpl[CM_NUM];   /* DELETE_ACTION_PLAYLIST */
+    static GtkWidget *mi_delipod[CM_NUM]; /* DELETE_ACTION_IPOD     */
+    static GtkWidget *mi_dellocal[CM_NUM];/* DELETE_ACTION_LOCAL    */
+    static GtkWidget *mi_deldb[CM_NUM];   /* DELETE_ACTION_DATABASE */
+    static GtkWidget *mi_delpcipod[CM_NUM]; /* DELETE_ACTION_IPOD   */
+    static GtkWidget *mi_delsep[CM_NUM];  /* separator              */
     static GtkWidget *mi_spl[CM_NUM];  /* edit smart playlist    */
-    static GtkWidget *mi_ipod_all[CM_NUM];/* DELETE_ACTION_IPOD (all
+    static GtkWidget *mi_delipod_all[CM_NUM];/* DELETE_ACTION_IPOD (all
 					   * tracks)      */
-    static GtkWidget *mi_db_all[CM_NUM];  /* DELETE_ACTION_DATABASE
+    static GtkWidget *mi_deldb_all[CM_NUM];  /* DELETE_ACTION_DATABASE
 					   * (all tracks  */
+/* FIXME: PODCASTS: remove Podcast menu */
+#if 0
+    static GtkWidget *mi_podcasts_sep[CM_NUM]; /* Podcasts Separator */
+    static GtkWidget *mi_podcasts_update[CM_NUM]; /* Update Podcasts */
+    static GtkWidget *mi_podcasts_prefs[CM_NUM];  /* Podcasts Prefs */
+#endif
 
     Playlist *pl;
 
@@ -298,31 +367,34 @@ create_context_menu(CM_type type)
 #if 0
 	hookup_mi (menu[type], _("Edit"), NULL, G_CALLBACK (edit_entries));
 #endif
-	hookup_mi (menu[type], _("Play Now"), "gtk-cdrom",
+	hookup_mi (menu[type], _("Play Now"), GTK_STOCK_CDROM,
 		   G_CALLBACK (play_entries_now), NULL);
-	hookup_mi (menu[type], _("Enqueue"), "gtk-cdrom",
+	hookup_mi (menu[type], _("Enqueue"), GTK_STOCK_CDROM,
 		   G_CALLBACK (play_entries_enqueue), NULL);
-	mi_exp[type] = hookup_mi (menu[type],
-				  _("Export Tracks"), "gtk-floppy",
+	mi_exp[type] = hookup_mi (menu[type], 
+				  _("Export Tracks"), GTK_STOCK_FLOPPY,
 				  G_CALLBACK (export_entries), NULL);
-	hookup_mi (menu[type], _("Create Playlist File"), "gtk-floppy",
+	hookup_mi (menu[type], _("Create Playlist File"), GTK_STOCK_FLOPPY,
 		   G_CALLBACK (create_playlist_file), NULL);
-	hookup_mi (menu[type], _("Update"), "gtk-refresh",
+	hookup_mi (menu[type], _("Edit Details"), NULL,
+		   G_CALLBACK (edit_details_entries), NULL);
+	hookup_mi (menu[type], _("Update"), GTK_STOCK_REFRESH,
 		   G_CALLBACK (update_entries), NULL);
-	hookup_mi (menu[type], _("Sync Dirs"), "gtk-refresh",
+	hookup_mi (menu[type], _("Sync Dirs"), GTK_STOCK_REFRESH,
 		   G_CALLBACK (sync_dirs_entries), NULL);
 	hookup_mi (menu[type], _("Normalize"), NULL,
 		   G_CALLBACK (normalize_entries), NULL);
 	hookup_mi (menu[type], _("Create new Playlist"),
-		   "gtk-justify-left",
+		   GTK_STOCK_JUSTIFY_LEFT,
 		   G_CALLBACK (create_playlist_from_entries), NULL);
 	mi_spl[type] = hookup_mi (menu[type], _("Edit Smart Playlist"),
-				  "gtk-properties",
+				  GTK_STOCK_PROPERTIES,
 				  G_CALLBACK (edit_spl), NULL);
 
 	if (type == CM_ST)
 	{
-	    hookup_mi (menu[type], _("Alphabetize"), "gtk-sort-ascending",
+	    hookup_mi (menu[type], _("Alphabetize"),
+		       GTK_STOCK_SORT_ASCENDING,
 		       G_CALLBACK (alphabetize), NULL);
 /* example for sub menus!
 	    GtkWidget *mi;
@@ -332,71 +404,116 @@ create_context_menu(CM_type type)
 	    sub = gtk_menu_new ();
 	    gtk_widget_show (sub);
 	    gtk_menu_item_set_submenu (GTK_MENU_ITEM (mi), sub);
-	    hookup_mi (sub, _("Ascending"), "gtk-sort-ascending",
+	    hookup_mi (sub, _("Ascending"), GTK_STOCK_SORT_ASCENDING,
 		       G_CALLBACK (alphabetize_ascending), NULL);
-	    hookup_mi (sub, _("Descending"), "gtk-sort-descending",
+	    hookup_mi (sub, _("Descending"), GTK_STOCK_SORT_DESCENDING,
 		       G_CALLBACK (alphabetize_descending), NULL);
-	    hookup_mi (sub, _("Reset"), "gtk-undo",
+	    hookup_mi (sub, _("Reset"), GTK_STOCK_UNDO,
 	               G_CALLBACK (reset_alphabetize), NULL);
 */
 	}
 	if ((type == CM_ST) || (type == CM_TM))
 	{
-	    mi_sep[type] = add_separator (menu[type]);
-	    mi_ipod[type] = hookup_mi (menu[type],
-				       _("Delete From iPod"),
-				       "gtk-delete",
-				       G_CALLBACK (delete_entries),
-				       (gpointer)DELETE_ACTION_IPOD);
-	    mi_local[type] = hookup_mi (menu[type],
-					_("Delete From Harddisk"),
-					"gtk-delete",
-					G_CALLBACK (delete_entries),
-					(gpointer)DELETE_ACTION_LOCAL);
-	    mi_db[type] = hookup_mi (menu[type],
-				     _("Delete From Database"),
-				     "gtk-delete",
-				     G_CALLBACK (delete_entries),
-				     (gpointer)DELETE_ACTION_DATABASE);
-	    mi_pl[type] = hookup_mi (menu[type],
-				     _("Delete From Playlist"),
-				     "gtk-delete",
-				     G_CALLBACK (delete_entries),
-				     (gpointer)DELETE_ACTION_PLAYLIST);
+	    mi_delsep[type] = add_separator (menu[type]);
+	    mi_delipod[type] =
+		hookup_mi (menu[type],
+			   _("Delete From iPod"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_IPOD));
+	    mi_dellocal[type] = 
+		hookup_mi (menu[type],
+			   _("Delete From Harddisk"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_LOCAL));
+	    mi_deldb[type] =
+		hookup_mi (menu[type],
+			   _("Delete From Database"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_DATABASE));
+	    mi_delpl[type] =
+		hookup_mi (menu[type],
+			   _("Delete From Playlist"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_PLAYLIST));
 	}
+#if LOCALDEBUG
+	/* This is for debugging purposes -- this allows to inspect
+	 * any track with a custom function */
+	if (type == CM_TM)
+	{
+	    hookup_mi (menu[type], "Special", GTK_STOCK_STOP,
+		       G_CALLBACK (do_special), NULL);
+	}
+#endif
 	if (type == CM_PM)
 	{
-	    mi_sep[type] = add_separator (menu[type]);
-	    mi_ipod[type] = hookup_mi (menu[type],
-				       _("Delete Including Tracks"),
-				       "gtk-delete",
-				       G_CALLBACK (delete_entries),
-				       (gpointer)DELETE_ACTION_IPOD);
-	    mi_local[type] = hookup_mi (menu[type],
-					_("Delete Including Tracks (Harddisk)"),
-					"gtk-delete",
-					G_CALLBACK (delete_entries),
-					(gpointer)DELETE_ACTION_LOCAL);
-	    mi_db[type] = hookup_mi (menu[type],
-				     _("Delete Including Tracks (Database)"),
-				     "gtk-delete",
-				     G_CALLBACK (delete_entries),
-				     (gpointer)DELETE_ACTION_DATABASE);
-	    mi_pl[type] = hookup_mi (menu[type],
-				     _("Delete But Keep Tracks"),
-				     "gtk-delete",
-				     G_CALLBACK (delete_entries),
-				     (gpointer)DELETE_ACTION_PLAYLIST);
-	    mi_ipod_all[type] = hookup_mi (menu[type],
-					   _("Remove All Tracks from iPod"),
-					   "gtk-delete",
-					   G_CALLBACK (delete_entries),
-					   (gpointer)DELETE_ACTION_IPOD);
-	    mi_db_all[type] = hookup_mi (menu[type],
-					 _("Remove All Tracks from Database"),
-					 "gtk-delete",
-					 G_CALLBACK (delete_entries),
-					 (gpointer)DELETE_ACTION_DATABASE);
+	    mi_delsep[type] = add_separator (menu[type]);
+	    mi_delipod[type] =
+		hookup_mi (menu[type],
+			   _("Delete Including Tracks"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_IPOD));
+	    mi_dellocal[type] =
+		hookup_mi (menu[type],
+			   _("Delete Including Tracks (Harddisk)"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_LOCAL));
+	    mi_deldb[type] =
+		hookup_mi (menu[type],
+			   _("Delete Including Tracks (Database)"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_DATABASE));
+	    mi_delpl[type] =
+		hookup_mi (menu[type],
+			   _("Delete But Keep Tracks"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_PLAYLIST));
+	    mi_delipod_all[type] =
+		hookup_mi (menu[type],
+			   _("Remove All Tracks from iPod"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_IPOD));
+	    mi_deldb_all[type] =
+		hookup_mi (menu[type],
+			   _("Remove All Tracks from Database"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_DATABASE));
+
+	    mi_delpcipod[type] =
+		hookup_mi (menu[type],
+			   _("Remove All Podcasts from iPod"),
+			   GTK_STOCK_DELETE,
+			   G_CALLBACK (delete_entries),
+			   GINT_TO_POINTER (DELETE_ACTION_IPOD));
+
+/* FIXME: PODCASTS: remove Podcast menu */
+#if 0
+	    mi_podcasts_sep[type] = add_separator (menu[type]);
+
+	    mi_podcasts_update[type] =
+		hookup_mi (menu[type],
+			   _("Update Podcasts"),
+			   GTK_STOCK_REFRESH,
+			   G_CALLBACK (podcast_fetch),
+			   GINT_TO_POINTER (DELETE_ACTION_DATABASE));
+
+	    mi_podcasts_prefs[type] =
+		hookup_mi (menu[type],
+			   _("Podcasts Preferences"),
+			   GTK_STOCK_PREFERENCES,
+			   G_CALLBACK (prefs_window_podcasts),
+			   GINT_TO_POINTER (DELETE_ACTION_DATABASE));
+#endif
 	}
     }
     /* Make sure, only available options are displayed */
@@ -410,95 +527,107 @@ create_context_menu(CM_type type)
 	switch (type)
 	{
 	case CM_PM:
+	    gtk_widget_hide (mi_spl[type]);
+	    gtk_widget_hide (mi_dellocal[type]);
+	    gtk_widget_hide (mi_delpl[type]);
+	    gtk_widget_hide (mi_deldb[type]);
+	    gtk_widget_hide (mi_deldb_all[type]);
+	    gtk_widget_hide (mi_delsep[type]);
+	    gtk_widget_hide (mi_delipod[type]);
+	    gtk_widget_hide (mi_delipod_all[type]);
+	    gtk_widget_hide (mi_delpcipod[type]);
+	    gtk_widget_hide (mi_dellocal[type]);
+/* FIXME: PODCASTS: remove Podcast menu */
+#if 0
+	    gtk_widget_hide (mi_podcasts_sep[type]);
+	    gtk_widget_hide (mi_podcasts_update[type]);
+	    gtk_widget_hide (mi_podcasts_prefs[type]);
+#endif
 	    if (pl->is_spl)
 	    {
 		gtk_widget_show (mi_spl[type]);
 	    }
-	    else
-	    {
-		gtk_widget_hide (mi_spl[type]);
-	    }
 	    if (itdb->usertype & GP_ITDB_TYPE_IPOD)
 	    {
-		gtk_widget_hide (mi_local [type]);
-		gtk_widget_hide (mi_db [type]);
-		gtk_widget_hide (mi_db_all [type]);
-		if (pl->type == ITDB_PL_TYPE_MPL)
+		if (itdb_playlist_is_mpl (pl))
 		{
-		    gtk_widget_hide (mi_sep [type]);
-		    gtk_widget_hide (mi_ipod [type]);
-		    gtk_widget_hide (mi_pl [type]);
-		    gtk_widget_show (mi_ipod_all [type]);
+		    gtk_widget_show (mi_delipod_all[type]);
 		}
 		else
 		{
-		    gtk_widget_show (mi_sep [type]);
-		    gtk_widget_show (mi_ipod [type]);
-		    gtk_widget_show (mi_pl [type]);
-		    gtk_widget_hide (mi_ipod_all [type]);
+		    if (itdb_playlist_is_podcasts (pl))
+		    {
+			gtk_widget_show (mi_delpcipod[type]);
+		    }
+		    else
+		    {
+			/* FIXME: PODCASTS: remove Podcast menu */
+			/*
+			gtk_widget_show (mi_delsep[type]);
+			gtk_widget_show (mi_delipod[type]);
+			gtk_widget_show (mi_delpl[type]);
+			*/
+		    }
 		}
 	    }
 	    if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
 	    {
-		gtk_widget_hide (mi_ipod [type]);
-		gtk_widget_hide (mi_ipod_all [type]);
-		if (pl->type == ITDB_PL_TYPE_MPL)
+		if (itdb_playlist_is_mpl (pl))
 		{
-		    gtk_widget_hide (mi_sep [type]);
-		    gtk_widget_hide (mi_local [type]);
-		    gtk_widget_hide (mi_db [type]);
-		    gtk_widget_hide (mi_pl [type]);
-		    gtk_widget_show (mi_db_all [type]);
+		    gtk_widget_show (mi_deldb_all[type]);
 		}
 		else
 		{
-		    gtk_widget_show (mi_sep [type]);
-		    gtk_widget_show (mi_local [type]);
-		    gtk_widget_show (mi_db [type]);
-		    gtk_widget_show (mi_pl [type]);
-		    gtk_widget_hide (mi_db_all [type]);
+		    gtk_widget_show (mi_delsep[type]);
+		    gtk_widget_show (mi_dellocal[type]);
+		    gtk_widget_show (mi_deldb[type]);
+		    gtk_widget_show (mi_delpl[type]);
 		}
 	    }
+
+	    if (itdb->usertype & GP_ITDB_TYPE_PODCASTS)
+	    {
+		gtk_widget_show (mi_delsep[type]);
+		/* FIXME: PODCASTS: remove Podcast menu */
+		/*
+		gtk_widget_show (mi_podcasts_sep[type]);
+		gtk_widget_show (mi_podcasts_update[type]);
+		gtk_widget_show (mi_podcasts_prefs[type]);
+		*/
+	    }
 	    break;
 	case CM_ST:
 	case CM_TM:
+	    gtk_widget_hide (mi_spl[type]);
+	    gtk_widget_hide (mi_dellocal[type]);
+	    gtk_widget_hide (mi_deldb[type]);
+	    gtk_widget_hide (mi_delpl[type]);
+	    gtk_widget_hide (mi_delipod[type]);
+
 	    if (pl->is_spl)
 	    {
 		gtk_widget_show (mi_spl[type]);
 	    }
-	    else
-	    {
-		gtk_widget_hide (mi_spl[type]);
-	    }
 	    if (itdb->usertype & GP_ITDB_TYPE_IPOD)
 	    {
-		gtk_widget_hide (mi_local [type]);
-		gtk_widget_hide (mi_db [type]);
-		if (pl->type == ITDB_PL_TYPE_MPL)
+		gtk_widget_show (mi_delipod[type]);
+		if (!itdb_playlist_is_mpl (pl) &&
+		    !itdb_playlist_is_podcasts (pl))
 		{
-		    gtk_widget_show (mi_ipod [type]);
-		    gtk_widget_hide (mi_pl [type]);
-		}
-		else
-		{
-		    gtk_widget_show (mi_ipod [type]);
-		    gtk_widget_show (mi_pl [type]);
+		    gtk_widget_show (mi_delpl[type]);
 		}
 	    }
 	    if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
 	    {
-		gtk_widget_hide (mi_ipod [type]);
-		if (pl->type == ITDB_PL_TYPE_MPL)
+		gtk_widget_show (mi_dellocal[type]);
+		gtk_widget_show (mi_deldb[type]);
+		/* actually, local repositories are not supposed to
+		   have podcasts playlists, but for completeness' sake
+		   I'll test anyway*/
+		if(!itdb_playlist_is_mpl (pl) &&
+		   !itdb_playlist_is_podcasts (pl))
 		{
-		    gtk_widget_show (mi_local [type]);
-		    gtk_widget_show (mi_db [type]);
-		    gtk_widget_hide (mi_pl [type]);
-		}
-		else
-		{
-		    gtk_widget_show (mi_local [type]);
-		    gtk_widget_show (mi_db [type]);
-		    gtk_widget_show (mi_pl [type]);
+		    gtk_widget_show (mi_delpl[type]);
 		}
 	    }
 	    break;
