@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-18 00:09:52 jcs>
+/* Time-stamp: <2005-12-14 23:13:26 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: display.c,v 1.116 2005/06/18 15:02:51 jcsjcs Exp $
+|  $Id: display.c,v 1.129 2005/12/11 08:52:30 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -35,11 +35,13 @@
 #include <stdlib.h>
 #include "display_private.h"
 #include "info.h"
+#include "details.h"
 #include "prefs.h"
 #include "prefs_window.h"
 #include "misc.h"
 #include "misc_track.h"
 #include "tools.h"
+#include "podcast.h"
 
 GtkWidget *gtkpod_window = NULL;
 
@@ -75,7 +77,7 @@ void display_create (void)
     st_set_default_sizes ();
     pm_create_treeview ();
     /* Hide the "stop_button" */
-    stop_button = glade_xml_get_widget (main_window_xml, "stop_button");
+    stop_button = gtkpod_xml_get_widget (main_window_xml, "stop_button");
     if (stop_button) gtk_widget_hide (stop_button);
     /* Hide/Show the toolbar */
     display_show_hide_toolbar ();
@@ -83,10 +85,9 @@ void display_create (void)
     display_show_hide_tooltips ();
     /* change standard g_print () handler */
     g_set_print_handler ((GPrintFunc)gtkpod_warning);
-    /* initialize sorting */
-    tm_sort (prefs_get_tm_sortcol (), prefs_get_tm_sort ());
+
     /* activate the delete menus correctly */
-    display_adjust_delete_menus ();
+    display_adjust_menus ();
     /* activate/deactive the menu item 'check iPod' */
     display_set_check_ipod_menu ();
     /* activate status bars */
@@ -98,6 +99,10 @@ void display_create (void)
     display_set_info_window_menu ();
     /* check if info window should be opened */
     if (prefs_get_info_window ())  info_open_window ();
+
+    /* if we need to fetch podcasts, then do so */
+/* FIXME: PODCASTS: remove Podcast menu */
+/*     if (prefs_get_pc_auto_fetch ())  podcast_fetch(); */
 }
 
 /* redisplay the entire display (playlists, sort tabs, track view) and
@@ -156,7 +161,7 @@ display_disable_gtkpod_import_buttons(void)
 
     g_return_if_fail (gtkpod_window);
 
-    if((w = glade_xml_get_widget (main_window_xml, "import_button")))
+    if((w = gtkpod_xml_get_widget (main_window_xml, "import_button")))
     {
 	gtk_widget_set_sensitive(w, FALSE);
 	/* in case this widget has been blocked, we need to tell
@@ -164,7 +169,7 @@ display_disable_gtkpod_import_buttons(void)
 	update_blocked_widget (w, FALSE);
     }
 
-    if((w = glade_xml_get_widget (main_window_xml, "import_itunes_mi")))
+    if((w = gtkpod_xml_get_widget (main_window_xml, "import_itunes_mi")))
     {
 	gtk_widget_set_sensitive(w, FALSE);
 	/* in case this widget has been blocked, we need to tell
@@ -175,41 +180,185 @@ display_disable_gtkpod_import_buttons(void)
 
 
 /* make sure only suitable delete menu items are available */
-void display_adjust_delete_menus (void)
+void display_adjust_menus (void)
 {
-    GtkWidget *d  = glade_xml_get_widget (main_window_xml, "delete_menu");
-    GtkWidget *dp = glade_xml_get_widget (main_window_xml, "delete_playlist_menu");
-    GtkWidget *df  = glade_xml_get_widget (main_window_xml, "delete_full_menu");
-    GtkWidget *dfp = glade_xml_get_widget (main_window_xml, "delete_full_playlist_menu");
-#if 0
-/* not used */
-    GtkWidget *de = glade_xml_get_widget (main_window_xml, "delete_tab_entry_menu");
-    GtkWidget *dt = glade_xml_get_widget (main_window_xml, "delete_tracks_menu");
-    GtkWidget *dfe = glade_xml_get_widget (main_window_xml,
-				    "delete_full_tab_entry_menu");
-    GtkWidget *dft = glade_xml_get_widget (main_window_xml, "delete_full_tracks_menu");
-#endif
+    GtkWidget *delete, *edit;
+    GtkWidget *dtfpl, *dtfip, *dtfdb, *dtfhd;
+    GtkWidget *defpl, *defip, *defdb, *defhd;
+    GtkWidget *dpl, *dpltfip, *dpltfdb, *dpltfhd;
+    GtkWidget *dsep1, *dsep2;
+    GtkWidget *espl, *w;
+    Playlist *pl;
+
+    delete = gtkpod_xml_get_widget (main_window_xml, "delete_menu");
+    edit = gtkpod_xml_get_widget (main_window_xml, "edit_menu");
+    dtfpl = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_tracks_from_playlist");
+    dtfip = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_tracks_from_ipod");
+    dtfdb = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_tracks_from_database");
+    dtfhd = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_tracks_from_harddisk");
+    defpl = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_entry_from_playlist");
+    defip = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_entry_from_ipod");
+    defdb = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_entry_from_database");
+    defhd = gtkpod_xml_get_widget (main_window_xml,
+				   "delete_selected_entry_from_harddisk");
+    dpl = gtkpod_xml_get_widget (main_window_xml,
+				 "delete_selected_playlist");
+    dpltfip = gtkpod_xml_get_widget (main_window_xml,
+				     "delete_selected_playlist_including_tracks_from_ipod");
+    dpltfdb = gtkpod_xml_get_widget (main_window_xml,
+				     "delete_selected_playlist_including_tracks_from_database");
+    dpltfhd = gtkpod_xml_get_widget (main_window_xml,
+				     "delete_selected_playlist_including_tracks_from_harddisk");
+    dsep1 = gtkpod_xml_get_widget (main_window_xml, "delete_separator1");
+    dsep2 = gtkpod_xml_get_widget (main_window_xml, "delete_separator2");
+    espl = gtkpod_xml_get_widget (main_window_xml,
+				  "edit_smart_playlist");
+
+    /* FIXME: PODCASTS: remove Podcast menu */
+    w = gtkpod_xml_get_widget (main_window_xml, "update_podcasts");
+    gtk_widget_hide (w);
+    w = gtkpod_xml_get_widget (main_window_xml, "update_podcasts_sep");
+    gtk_widget_hide (w);
+
+    pl = pm_get_selected_playlist ();
 
-    Playlist *pl = pm_get_selected_playlist ();
     if (pl == NULL)
     {
-	gtk_widget_set_sensitive (d, FALSE);
-	gtk_widget_set_sensitive (df, FALSE);
+	gtk_widget_set_sensitive (delete, FALSE);
+	gtk_widget_set_sensitive (edit, FALSE);
     }
     else
     {
-	switch (pl->type)
+	iTunesDB *itdb = pl->itdb;
+	g_return_if_fail (itdb);
+
+	gtk_widget_set_sensitive (delete, TRUE);
+	gtk_widget_set_sensitive (edit, TRUE);
+
+	gtk_widget_hide (dtfpl);
+	gtk_widget_hide (dtfip);
+	gtk_widget_hide (dtfdb);
+	gtk_widget_hide (dtfhd);
+
+	gtk_widget_hide (defpl);
+	gtk_widget_hide (defip);
+	gtk_widget_hide (defdb);
+	gtk_widget_hide (defhd);
+
+	gtk_widget_hide (dpl);
+	gtk_widget_hide (dpltfip);
+	gtk_widget_hide (dpltfdb);
+	gtk_widget_hide (dpltfhd);
+
+	gtk_widget_hide (dsep1);
+	gtk_widget_hide (dsep2);
+
+	gtk_widget_set_sensitive (espl, FALSE);
+
+	if (pl->is_spl)
 	{
-	case ITDB_PL_TYPE_NORM:
-	    gtk_widget_set_sensitive (d, TRUE);
-	    gtk_widget_set_sensitive (df, TRUE);
-	    gtk_widget_set_sensitive (dp, TRUE);
-	    gtk_widget_set_sensitive (dfp, TRUE);
-	    break;
-	case ITDB_PL_TYPE_MPL:
-	    gtk_widget_set_sensitive (d, FALSE);
-	    gtk_widget_set_sensitive (df, TRUE);
-	    gtk_widget_set_sensitive (dfp, FALSE);
+	    gtk_widget_set_sensitive (espl, TRUE);
+	}
+
+	if (itdb->usertype & GP_ITDB_TYPE_IPOD)
+	{
+	    if (itdb_playlist_is_mpl (pl))
+	    {
+		gtk_widget_show (dtfip);
+		gtk_widget_show (defip);
+	    }
+	    else
+	    {
+		if (itdb_playlist_is_podcasts (pl))
+		{
+		    gtk_widget_show (dtfip);
+		    gtk_widget_show (defip);
+		}
+		else
+		{
+		    gtk_widget_show (dpl);
+		    gtk_widget_show (dpltfip);
+
+		    gtk_widget_show (dsep1);
+
+		    gtk_widget_show (defpl);
+		    gtk_widget_show (defip);
+
+		    gtk_widget_show (dsep2);
+
+		    gtk_widget_show (dtfpl);
+		    gtk_widget_show (dtfip);
+		}
+	    }
+	}
+	if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
+	{
+	    if (itdb_playlist_is_mpl (pl))
+	    {
+		gtk_widget_show (dtfdb);
+		gtk_widget_show (dtfhd);
+
+		gtk_widget_show (dsep2);
+
+		gtk_widget_show (defdb);
+		gtk_widget_show (defhd);
+	    }
+	    else
+	    {
+		gtk_widget_show (dtfpl);
+		gtk_widget_show (dtfdb);
+		gtk_widget_show (dtfhd);
+
+		gtk_widget_show (dsep1);
+
+		gtk_widget_show (defpl);
+		gtk_widget_show (defdb);
+		gtk_widget_show (defhd);
+
+		gtk_widget_show (dsep2);
+
+		gtk_widget_show (dpl);
+		gtk_widget_show (dpltfdb);
+		gtk_widget_show (dpltfhd);
+	    }
+	}
+	if (itdb->usertype & GP_ITDB_TYPE_PODCASTS)
+	{
+	    if (itdb_playlist_is_mpl (pl))
+	    {
+		gtk_widget_show (dtfdb);
+		gtk_widget_show (dtfhd);
+
+		gtk_widget_show (dsep2);
+
+		gtk_widget_show (defdb);
+		gtk_widget_show (defhd);
+	    }
+	    else
+	    {
+		gtk_widget_show (dtfpl);
+		gtk_widget_show (dtfdb);
+		gtk_widget_show (dtfhd);
+
+		gtk_widget_show (dsep1);
+
+		gtk_widget_show (defpl);
+		gtk_widget_show (defdb);
+		gtk_widget_show (defhd);
+
+		gtk_widget_show (dsep2);
+
+		gtk_widget_show (dpl);
+		gtk_widget_show (dpltfdb);
+		gtk_widget_show (dpltfhd);
+	    }
 	}
     }
 }
@@ -218,8 +367,8 @@ void display_adjust_delete_menus (void)
    the prefs */
 void display_show_hide_toolbar (void)
 {
-    GtkWidget *tb = glade_xml_get_widget (main_window_xml, "toolbar");
-    GtkWidget *mi = glade_xml_get_widget (main_window_xml, "toolbar_menu");
+    GtkWidget *tb = gtkpod_xml_get_widget (main_window_xml, "toolbar");
+    GtkWidget *mi = gtkpod_xml_get_widget (main_window_xml, "toolbar_menu");
 
     if (prefs_get_display_toolbar ())
     {
@@ -238,7 +387,7 @@ void display_show_hide_toolbar (void)
    prefs. */
 void display_set_info_window_menu (void)
 {
-    GtkWidget *mi = glade_xml_get_widget (main_window_xml, "info_window_menu");
+    GtkWidget *mi = gtkpod_xml_get_widget (main_window_xml, "info_window_menu");
 
     if (prefs_get_info_window ())
     {
@@ -251,16 +400,14 @@ void display_set_info_window_menu (void)
 }
 
 /** Takes care about 'Check IPOD Files' Menu Item and makes it unavailable
- * if gtkpod is offline or DB wasn't imported.
+ * if gtkpod is offline.
  */
 void display_set_check_ipod_menu (void)
 {
     GtkWidget *w = NULL;
 
-    if((w = glade_xml_get_widget (main_window_xml, "check_ipod_files_mi")))
+    if((w = gtkpod_xml_get_widget (main_window_xml, "check_ipod_files_mi")))
         gtk_widget_set_sensitive(w, !prefs_get_offline());
-    else
-        g_warning ("check_ipod_files_mi(): Programming error: widget check_ipod_files_mi must be found\n");
 }
 
 /* make the tooltips visible or hide it depending on the value set in
@@ -280,8 +427,8 @@ void display_show_hide_tooltips (void)
 			    "main_tooltips_initialised")) return;
 
     mi = GTK_CHECK_MENU_ITEM (
-	glade_xml_get_widget (main_window_xml, "tooltips_menu"));
-    tb = GTK_TOOLBAR (glade_xml_get_widget (main_window_xml, "toolbar"));
+	gtkpod_xml_get_widget (main_window_xml, "tooltips_menu"));
+    tb = GTK_TOOLBAR (gtkpod_xml_get_widget (main_window_xml, "toolbar"));
     mt = g_object_get_data (G_OBJECT (gtkpod_window), "main_tooltips");
 
     g_return_if_fail (mi);
@@ -329,6 +476,7 @@ void display_update_default_sizes (void)
     st_update_default_sizes ();
     prefs_window_update_default_sizes ();
     info_update_default_sizes ();
+    details_update_default_sizes ();
 }
 
 
@@ -440,7 +588,7 @@ static void block_release_selection (gint inst, gint action,
     /* lookup stop_button */
     if (stop_button == NULL)
     {
-	stop_button = glade_xml_get_widget (main_window_xml, "stop_button");
+	stop_button = gtkpod_xml_get_widget (main_window_xml, "stop_button");
 	if (stop_button == NULL)
 	    g_warning ("Programming error: stop_button not found\n");
     }
@@ -651,8 +799,8 @@ void display_remove_autoscroll_row_timeout (GtkWidget *widget)
 
     g_return_if_fail (widget);
 
-    timeout = (guint)g_object_get_data (G_OBJECT (widget),
-					"scroll_row_timeout");
+    timeout = GPOINTER_TO_UINT(g_object_get_data (G_OBJECT (widget),
+					"scroll_row_timeout"));
 
     if (timeout != 0)
     {
@@ -667,7 +815,7 @@ static gint display_autoscroll_row_timeout (gpointer data)
     gint px, py;
     GdkModifierType mask;
     GdkRectangle vis_rect;
-    gint times;
+    guint times;
     gboolean resp = TRUE;
     const gint SCROLL_EDGE_SIZE = 12;
 
@@ -675,7 +823,7 @@ static gint display_autoscroll_row_timeout (gpointer data)
 
     gdk_threads_enter ();
 
-    times = (gint)g_object_get_data (G_OBJECT (data), "scroll_row_times");
+    times = GPOINTER_TO_UINT(g_object_get_data (G_OBJECT (data), "scroll_row_times"));
     
     gdk_window_get_pointer (gtk_tree_view_get_bin_window (treeview),
 			    &px, &py, &mask);
@@ -717,7 +865,7 @@ static gint display_autoscroll_row_timeout (gpointer data)
 	times = 0;
     }
     g_object_set_data (G_OBJECT (data), "scroll_row_times",
-		       (gpointer)times);
+		       GUINT_TO_POINTER(times));
     if (mask == 0)
     {
 	_remove_scroll_row_timeout (data);
@@ -734,7 +882,7 @@ void display_install_autoscroll_row_timeout (GtkWidget *widget)
 	guint timeout = g_timeout_add (75, display_autoscroll_row_timeout,
 				       widget);
 	g_object_set_data (G_OBJECT (widget), "scroll_row_timeout",
-			   (gpointer)timeout);
+			   GUINT_TO_POINTER(timeout));
     }
 }
 
@@ -753,10 +901,67 @@ void display_install_autoscroll_row_timeout (GtkWidget *widget)
    void create_add_files_dialog (void)
    void create_add_playlists_dialog(void)
    void dirbrowser_create (void)
-   void open_about_window ()
+   void open_about_window (void)
 */
 
 
+/* FIXME: PODCASTS: remove Podcast menu */
+void on_update_podcasts_activate (GtkButton       *button,
+				  gpointer         user_data)
+{
+#if 0
+    podcast_fetch ();
+#endif
+}
+
+void on_edit_details_selected_playlist (GtkMenuItem     *menuitem,
+					gpointer         user_data)
+{
+    Playlist *pl = pm_get_selected_playlist ();
+
+    if (!pl)
+    {
+	gtkpod_statusbar_message (_("No playlist selected"));
+	return;
+    }
+    details_edit (pl->members);
+}
+
+void on_edit_details_selected_tab_entry (GtkMenuItem     *menuitem,
+					 gpointer         user_data)
+{
+    gint inst = get_sort_tab_number (
+	_("Edit selected entry of which sort tab?"));
+
+    if (inst != -1)
+    {
+	TabEntry *entry = st_get_selected_entry (inst);
+	if (entry == NULL)
+	{  /* no entry selected */
+	    gtkpod_statusbar_message (_("No entry selected."));
+	    return;
+	}
+	details_edit (entry->members);
+    }
+}
+
+void on_edit_details_selected_tracks (GtkMenuItem     *menuitem,
+				      gpointer         user_data)
+{
+    GList *tracks = tm_get_selected_tracks ();
+
+    if (tracks)
+    {
+	details_edit (tracks);
+	g_list_free (tracks);
+    }
+    else
+    {
+	gtkpod_statusbar_message (_("No tracks selected"));
+    }
+}
+
+
 /* callback for "add new playlist" button */
 void
 on_new_playlist_button                 (GtkButton       *button,
@@ -778,7 +983,7 @@ void
 on_edit_preferences1_activate          (GtkMenuItem     *menuitem,
 					gpointer         user_data)
 {
-    if(!widgets_blocked)  prefs_window_create();
+    if(!widgets_blocked)  prefs_window_create (-1);
 }
 
 
@@ -807,64 +1012,157 @@ on_import_button_clicked               (GtkButton       *button,
 }
 
 
-void
-on_delete_tracks_activate               (GtkMenuItem     *menuitem,
-					gpointer         user_data)
+void on_edit_smart_playlist (GtkMenuItem *mi,
+			     gpointer data)
 {
-    g_print ("not supported yet");
-//    delete_track_head (FALSE);
+    Playlist *pl = pm_get_selected_playlist ();
+
+    if (!pl)
+    {
+	gtkpod_statusbar_message (_("No playlist selected"));
+	return;
+    }
+    spl_edit (pl);
+}
+
+
+static void delete_selected_tracks (DeleteAction deleteaction)
+{
+    GList *tracks = tm_get_selected_tracks ();
+
+    if (tracks)
+    {
+	delete_track_head (deleteaction);
+	g_list_free (tracks);
+    }
+    else
+    {
+	gtkpod_statusbar_message (_("No tracks selected"));
+    }
+}    
+
+static void delete_selected_entry (DeleteAction deleteaction,
+				   gchar *text)
+{
+    TabEntry *entry;
+    gint inst;
+
+    inst = get_sort_tab_number (text);
+    if (inst == -1) return;
+
+    entry = st_get_selected_entry (inst);
+    if (!entry)
+    {
+	gchar *str = g_strdup_printf(_("No entry selected in Sort Tab %d"),
+				     inst+1);
+	gtkpod_statusbar_message (str);
+	g_free (str);
+	return;
+    }
+    delete_entry_head (inst, deleteaction);
+}
+
+static void delete_selected_playlist (DeleteAction deleteaction)
+{
+    Playlist *pl = pm_get_selected_playlist ();
+
+    if (!pl)
+    {
+	gtkpod_statusbar_message (_("No playlist selected"));
+	return;
+    }
+    delete_playlist_head (deleteaction);
+}
+
+void on_delete_selected_tracks_from_database (GtkMenuItem *mi,
+					      gpointer data)
+{
+    delete_selected_tracks (DELETE_ACTION_DATABASE);
+}
+
+void
+on_delete_selected_playlist_including_tracks_from_harddisk (GtkMenuItem *mi,
+							    gpointer data)
+{
+    delete_selected_playlist (DELETE_ACTION_LOCAL);
+}
+
+
+void on_delete_selected_entry_from_database (GtkMenuItem *mi,
+					     gpointer data)
+{
+    delete_selected_entry (DELETE_ACTION_DATABASE, 
+			   _("Remove entry of which sort tab from database?"));
+}
+
+
+void on_delete_selected_entry_from_ipod (GtkMenuItem *mi,
+					 gpointer data)
+{
+    delete_selected_entry (DELETE_ACTION_IPOD,
+			   _("Remove tracks in selected entry of which filter tab from the iPod?"));
+}
+
+
+void on_delete_selected_tracks_from_playlist (GtkMenuItem *mi,
+					      gpointer data)
+{
+    delete_selected_tracks (DELETE_ACTION_PLAYLIST);
+}
+
+
+void on_delete_selected_tracks_from_harddisk (GtkMenuItem *mi,
+					      gpointer data)
+{
+    delete_selected_tracks (DELETE_ACTION_LOCAL);
+}
+
+
+void on_delete_selected_entry_from_harddisk (GtkMenuItem *mi,
+					     gpointer data)
+{
+    delete_selected_entry (DELETE_ACTION_LOCAL,
+			   _("Remove tracks in selected entry of which filter tab from the harddisk?"));
+}
+
+
+void on_delete_selected_tracks_from_ipod (GtkMenuItem *mi,
+					  gpointer data)
+{
+    delete_selected_tracks (DELETE_ACTION_IPOD);
+}
+
+
+void on_delete_selected_playlist (GtkMenuItem *mi,
+				  gpointer data)
+{
+    delete_selected_playlist (DELETE_ACTION_PLAYLIST);
 }
 
 
 void
-on_delete_playlist_activate                (GtkMenuItem     *menuitem,
-					gpointer         user_data)
+on_delete_selected_playlist_including_tracks_from_database (GtkMenuItem *mi,
+							    gpointer data)
 {
-    g_print ("not supported yet");
-//    delete_playlist_head (FALSE);
+    delete_selected_playlist (DELETE_ACTION_DATABASE);
 }
 
-void
-on_delete_tab_entry_activate           (GtkMenuItem     *menuitem,
-					gpointer         user_data)
-{
-    g_print ("not supported yet");
-/*     gint inst = get_sort_tab_number ( */
-/* 	_("Delete selected entry of which sort tab?")); */
 
-/*     if (inst != -1)   delete_entry_head (inst, FALSE); */
-}
-
-void
-on_delete_full_tracks_activate               (GtkMenuItem     *menuitem,
-					gpointer         user_data)
+void on_delete_selected_entry_from_playlist (GtkMenuItem *mi,
+					     gpointer data)
 {
-    g_print ("not supported yet");
-//     delete_track_head (TRUE);
+    delete_selected_entry (DELETE_ACTION_PLAYLIST,
+			   _("Remove tracks in selected entry of which filter tab from playlist?"));
 }
 
 
 void
-on_delete_full_playlist_activate                (GtkMenuItem     *menuitem,
-					gpointer         user_data)
+on_delete_selected_playlist_including_tracks_from_ipod (GtkMenuItem *mi,
+							gpointer data)
 {
-    g_print ("not supported yet");
-//    delete_playlist_head (TRUE);
+    delete_selected_playlist (DELETE_ACTION_IPOD);
 }
 
-void
-on_delete_full_tab_entry_activate           (GtkMenuItem     *menuitem,
-					gpointer         user_data)
-{
-    g_print ("not supported yet");
-/*     gint inst = get_sort_tab_number ( */
-/* 	_("Delete selected entry of which sort tab?")); */
-
-/*     if (inst != -1) */
-/*     { */
-/* 	delete_entry_head (inst, TRUE); */
-/*     } */
-}
 
 void
 on_ipod_directories_menu               (GtkMenuItem     *menuitem,
