@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-25 11:20:54 jcs>
+/* Time-stamp: <2005-12-04 23:45:22 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: file_itunesdb.c,v 1.55 2005/06/25 02:52:25 jcsjcs Exp $
+|  $Id: file_itunesdb.c,v 1.72 2005/12/04 16:00:39 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -57,6 +57,8 @@ struct track_extended_info
     guint ipod_id;
     gchar *pc_path_locale;
     gchar *pc_path_utf8;
+    gchar *thumb_path_locale;
+    gchar *thumb_path_utf8;
     gchar *md5_hash;
     gchar *charset;
     gchar *hostname;
@@ -88,7 +90,9 @@ static float extendedinfoversion = 0.0;
 
 
 /* fills in extended info if available */
-void fill_in_extended_info (Track *track)
+/* num/total are used to give updates in case the md5 checksums have
+   to be matched against the files which is very time consuming */
+void fill_in_extended_info (Track *track, gint32 total, gint32 num)
 {
   gint ipod_id=0;
   ExtraTrackData *etr;
@@ -106,6 +110,14 @@ void fill_in_extended_info (Track *track)
   }
   if (!sei && extendedinfohash_md5)
   {
+      gchar *buf = g_strdup_printf (
+	  _("Matching MD5 checksum for file %d/%d"),
+	  num, total);
+      gtkpod_statusbar_message (buf);
+      while (widgets_blocked && gtk_events_pending ())
+	  gtk_main_iteration ();
+      g_free (buf);
+
       if (!etr->md5_hash)
       {
 	  gchar *filename = get_file_name_on_ipod (track);
@@ -123,6 +135,10 @@ void fill_in_extended_info (Track *track)
 	  etr->pc_path_locale = g_strdup (sei->pc_path_locale);
       if (sei->pc_path_utf8 && !etr->pc_path_utf8)
 	  etr->pc_path_utf8 = g_strdup (sei->pc_path_utf8);
+      if (sei->thumb_path_locale && !etr->thumb_path_locale)
+	  etr->thumb_path_locale = g_strdup (sei->thumb_path_locale);
+      if (sei->thumb_path_utf8 && !etr->thumb_path_utf8)
+	  etr->thumb_path_utf8 = g_strdup (sei->thumb_path_utf8);
       if (sei->md5_hash && !etr->md5_hash)
 	  etr->md5_hash = g_strdup (sei->md5_hash);
       if (sei->charset && !etr->charset)
@@ -171,12 +187,14 @@ static void hash_delete (gpointer data)
 
     if (sei)
     {
-	C_FREE (sei->pc_path_locale);
-	C_FREE (sei->pc_path_utf8);
-	C_FREE (sei->md5_hash);
-	C_FREE (sei->charset);
-	C_FREE (sei->hostname);
-	C_FREE (sei->ipod_path);
+	g_free (sei->pc_path_locale);
+	g_free (sei->pc_path_utf8);
+	g_free (sei->thumb_path_locale);
+	g_free (sei->thumb_path_utf8);
+	g_free (sei->md5_hash);
+	g_free (sei->charset);
+	g_free (sei->hostname);
+	g_free (sei->ipod_path);
 	g_free (sei);
     }
 }
@@ -260,9 +278,8 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
 		{
 		    hash_matched = FALSE;
 		    gtkpod_warning (_("iTunesDB '%s' does not match checksum in extended information file '%s'\ngtkpod will try to match the information using MD5 checksums. This may take a long time.\n\n"), itunes, name);
-		    while (gtk_events_pending ())  gtk_main_iteration ();
-/*		    success = FALSE;
-		    break;*/
+		    while (widgets_blocked && gtk_events_pending ())
+			gtk_main_iteration ();
 		}
 		else
 		{
@@ -342,6 +359,10 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
 		sei->pc_path_locale = g_strdup (arg);
 	    else if (g_ascii_strcasecmp (line, "filename_utf8") == 0)
 		sei->pc_path_utf8 = g_strdup (arg);
+	    else if (g_ascii_strcasecmp (line, "thumbnail_locale") == 0)
+		sei->thumb_path_locale = g_strdup (arg);
+	    else if (g_ascii_strcasecmp (line, "thumbnail_utf8") == 0)
+		sei->thumb_path_utf8 = g_strdup (arg);
 	    else if (g_ascii_strcasecmp (line, "md5_hash") == 0)
 	    {   /* only accept hash value if version is >= 0.53 or
 		   PATH_MAX is 4096 -- in 0.53 I changed the MD5 hash
@@ -394,7 +415,7 @@ static gboolean read_extended_info (gchar *name, gchar *itunes)
 /* Import an iTunesDB and return an iTunesDB structure.
  * If @old_itdb is set, it will be merged into the newly imported
  * one. @old_itdb will not be changed.
- * @type: GP_ITDB_TYPE_LOCAL or GP_ITDB_TYPE_IPOD
+ * @type: GP_ITDB_TYPE_LOCAL/IPOD (bitwise flags!)
  * @mp: mount point of iPod (if reading an iPod iTunesDB)
  * @name_off: name of the iTunesDB in offline mode
  * @name_loc: name of iTunesDB (if reading a local file browser) */
@@ -408,12 +429,14 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
     ExtraiTunesDBData *eitdb;
     iTunesDB *itdb = NULL;
     GError *error = NULL;
+    gint32 total, num;
 
     g_return_val_if_fail (!(type & GP_ITDB_TYPE_LOCAL) || name_loc, NULL);
     g_return_val_if_fail (!(type & GP_ITDB_TYPE_IPOD) || 
 			  (mp && name_off), NULL);
     g_return_val_if_fail (cfgdir, NULL);
 
+    block_widgets ();
     if (prefs_get_offline() || (type & GP_ITDB_TYPE_LOCAL))
     { /* offline or local database - requires extended info */
 	gchar *name_ext;
@@ -532,13 +555,17 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	g_free (name_db);
     }
 
+    if (!itdb)
+    {
+	release_widgets ();
+	return NULL;
+    }
+
     /* add Extra*Data */
     gp_itdb_add_extra_full (itdb);
 
-    if (!itdb) return NULL;
-
     eitdb = itdb->userdata;
-    g_return_val_if_fail (eitdb, NULL);
+    g_return_val_if_fail (eitdb, (release_widgets(), NULL));
 
     /* fill in additional info */
     itdb->usertype = type;
@@ -546,26 +573,49 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
     {
 	if (prefs_get_offline ())
 	{
-	    itdb->mountpoint = g_strdup (mp);
+	    itdb_set_mountpoint (itdb, mp);
 	    g_free (itdb->filename);
 	    itdb->filename = NULL;
 	}
 	eitdb->offline_filename = g_strdup (name_off);
     }	    
 
+    total = g_list_length (itdb->tracks);
+    num = 1;
     /* validate all tracks and fill in extended info */
     for (gl=itdb->tracks; gl; gl=gl->next)
     {
 	Track *track = gl->data;
-	g_return_val_if_fail (track, NULL);
-	fill_in_extended_info (track);
+	ExtraTrackData *etr;
+	g_return_val_if_fail (track, (release_widgets(), NULL));
+	etr = track->userdata;
+	g_return_val_if_fail (etr, (release_widgets(), NULL));
+	fill_in_extended_info (track, total, num);
 	gp_track_validate_entries (track);
+	/* set new default value for flag1 (unknown) */
+	if (track->flag1 == 0)
+	    track->flag1 = 0x02;
+	/* set unk208 to audio if unset (important only for iPod Video) */
+	if (track->unk208 == 0)
+	    track->unk208 = 0x00000001;
+	/* restore deleted thumbnails */
+	if ((track->artwork->thumbnails == NULL) &&
+	    (strlen (etr->thumb_path_locale) != 0))
+	{
+	    /* !! gp_track_set_thumbnails() writes on
+	       etr->thumb_path_locale, so we need to g_strdup()
+	       first !! */
+	    gchar *filename = g_strdup (etr->thumb_path_locale);
+	    gp_track_set_thumbnails (track, filename);
+	    g_free (filename);
+	}
+	++num;
     }
     /* take over the pending deletion information */
     while (extendeddeletion)
     {
 	Track *track = extendeddeletion->data;
-	g_return_val_if_fail (track, NULL);
+	g_return_val_if_fail (track, (release_widgets(), NULL));
 	mark_track_for_deletion (itdb, track);
 	extendeddeletion = g_list_delete_link (extendeddeletion,
 					       extendeddeletion);
@@ -588,15 +638,15 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	GHashTable *track_hash = g_hash_table_new (g_direct_hash,
 						   g_direct_equal);
 	Playlist *mpl = itdb_playlist_mpl (itdb);
-	g_return_val_if_fail (mpl, NULL);
-	g_return_val_if_fail (old_eitdb, NULL);
+	g_return_val_if_fail (mpl, (release_widgets(), NULL));
+	g_return_val_if_fail (old_eitdb, (release_widgets(), NULL));
 
 	/* add tracks from @old_itdb to new itdb */
 	for (gl=old_itdb->tracks; gl; gl=gl->next)
 	{
 	    Track *duptr, *addtr;
 	    Track *track = gl->data;
-	    g_return_val_if_fail (track, NULL);
+	    g_return_val_if_fail (track, (release_widgets(), NULL));
 	    duptr = itdb_track_duplicate (track);
 	    /* add to database -- if duplicate detection is on and the
 	       same track already exists in the database, the already
@@ -615,18 +665,34 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	    GList *glm;
 	    Playlist *duppl;
 	    Playlist *pl = gl->next->data; /* skip MPL */
-	    g_return_val_if_fail (pl, NULL);
+	    g_return_val_if_fail (pl, (release_widgets(), NULL));
 	    duppl = itdb_playlist_duplicate (pl);
 	    /* switch members */
 	    for (glm=duppl->members; glm; glm=glm->next)
 	    {
 		Track *newtr;
-		g_return_val_if_fail (glm->data, NULL);
+		g_return_val_if_fail (glm->data, (release_widgets(), NULL));
 		newtr = g_hash_table_lookup (track_hash, glm->data);
-		g_return_val_if_fail (newtr, NULL);
+		g_return_val_if_fail (newtr, (release_widgets(), NULL));
 		glm->data = newtr;
 	    }
-	    itdb_playlist_add (itdb, duppl, -1);
+	    /* if it's the podcasts list, don't add the list again if
+	       it already exists, but only the members. */
+	    if (itdb_playlist_is_podcasts (duppl) &&
+		itdb_playlist_podcasts (itdb))
+	    {
+		Playlist *podcasts = itdb_playlist_podcasts (itdb);
+		for (glm=duppl->members; glm; glm=glm->next)
+		{
+		    g_return_val_if_fail (glm->data, (release_widgets(), NULL));
+		    itdb_playlist_add_track (podcasts, glm->data, -1);
+		}
+		itdb_playlist_free (duppl);
+	    }
+	    else
+	    {
+		itdb_playlist_add (itdb, duppl, -1);
+	    }
 	    gl = gl->next;
 	}
 	g_hash_table_destroy (track_hash);
@@ -634,8 +700,10 @@ iTunesDB *gp_import_itdb (iTunesDB *old_itdb, const gint type,
 	eitdb->data_changed = old_eitdb->data_changed;
     }
 
-    /* update all SPLs */
-    itdb_spl_update_all (itdb);
+    /* update all live SPLs */
+    itdb_spl_update_live (itdb);
+
+    release_widgets();
 
     return itdb;
 }
@@ -849,17 +917,19 @@ static gboolean write_extended_info (iTunesDB *itdb)
       fprintf (fp, "id=%d\n", track->id);
       if (etr->hostname)
 	  fprintf (fp, "hostname=%s\n", etr->hostname);
-      if (strlen (etr->pc_path_locale) != 0)
+      if (etr->pc_path_locale && *etr->pc_path_locale)
 	  fprintf (fp, "filename_locale=%s\n", etr->pc_path_locale);
-      if (strlen (etr->pc_path_utf8) != 0)
+      if (etr->pc_path_utf8 && *etr->pc_path_utf8)
 	  fprintf (fp, "filename_utf8=%s\n", etr->pc_path_utf8);
+      if (etr->thumb_path_locale && *etr->thumb_path_locale)
+	  fprintf (fp, "thumbnail_locale=%s\n", etr->thumb_path_locale);
+      if (etr->thumb_path_utf8 && *etr->thumb_path_utf8)
+	  fprintf (fp, "thumbnail_utf8=%s\n", etr->thumb_path_utf8);
       /* this is just for convenience for people looking for a track
 	 on the ipod away from gktpod/itunes etc. */
-      if (strlen (track->ipod_path) != 0)
-	  fprintf (fp, "filename_ipod=%s\n", track->ipod_path);
-      if (etr->md5_hash)
+      if (etr->md5_hash && *etr->md5_hash)
 	  fprintf (fp, "md5_hash=%s\n", etr->md5_hash);
-      if (etr->charset)
+      if (etr->charset && *etr->charset)
 	  fprintf (fp, "charset=%s\n", etr->charset);
       if (!track->transferred && etr->oldsize)
 	  fprintf (fp, "oldsize=%d\n", etr->oldsize);
@@ -911,14 +981,14 @@ static gboolean write_extended_info (iTunesDB *itdb)
 /* returns: int result (of remove()) */
 static gpointer th_remove (gpointer filename)
 {
-    int result;
+    guint result;
 
     result = remove ((gchar *)filename);
     g_mutex_lock (mutex);
     mutex_data = TRUE; /* signal that thread will end */
     g_cond_signal (cond);
     g_mutex_unlock (mutex);
-    return (gpointer)result;
+    return GUINT_TO_POINTER(result);
 }
 #endif
 
@@ -935,7 +1005,7 @@ static gpointer th_copy (gpointer s)
     etr = track->userdata;
     g_return_val_if_fail (etr, NULL);
 
-    itdb_cp_track_to_ipod (mount, track, etr->pc_path_locale, &error);
+    itdb_cp_track_to_ipod (track, etr->pc_path_locale, &error);
     g_free (mount);
     /* delete old size */
     if (track->transferred) etr->oldsize = 0;
@@ -959,7 +1029,7 @@ static void file_dialog_abort (gboolean *abort_flag)
 /* check if iPod directory stucture is present */
 static gboolean ipod_dirs_present (gchar *mountpoint)
 {
-    const gchar *music[] = {"iPod_Control","Music",NULL},
+    const gchar *music[] = {"iPod_Control", "Music", "F00", NULL},
       *itunes[] = {"iPod_Control","iTunes",NULL};
     gchar *file;
     gboolean result = TRUE;
@@ -1041,7 +1111,6 @@ static gboolean delete_files (iTunesDB *itdb)
   gboolean result = TRUE;
   static gboolean abort_flag;
   ExtraiTunesDBData *eitdb;
-  const gchar *mp = NULL;
 #ifdef G_THREADS_ENABLED
   GThread *thread = NULL;
   GTimeVal gtime;
@@ -1049,6 +1118,8 @@ static gboolean delete_files (iTunesDB *itdb)
   if (!cond) cond = g_cond_new ();
 #endif
 
+
+
   g_return_val_if_fail (itdb, FALSE);
   eitdb = itdb->userdata;
   g_return_val_if_fail (eitdb, FALSE);
@@ -1060,8 +1131,7 @@ static gboolean delete_files (iTunesDB *itdb)
 
   if (itdb->usertype & GP_ITDB_TYPE_IPOD)
   {
-      mp = prefs_get_ipod_mount ();
-      g_return_val_if_fail (mp, FALSE);
+      g_return_val_if_fail (itdb->mountpoint, FALSE);
   }
 
   abort_flag = FALSE;
@@ -1081,7 +1151,9 @@ static gboolean delete_files (iTunesDB *itdb)
 
       if (itdb->usertype & GP_ITDB_TYPE_IPOD)
       {
-	  filename = get_file_name_on_ipod (track);
+	  track->itdb = itdb;
+	  filename = itdb_filename_on_ipod (track);
+	  track->itdb = NULL;
       }
       if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
       {
@@ -1090,7 +1162,7 @@ static gboolean delete_files (iTunesDB *itdb)
 
       if(filename)
       {
-	  gint rmres;
+	  guint rmres;
 #ifdef G_THREADS_ENABLED
 	  mutex_data = FALSE;
 	  thread = g_thread_create (th_remove, filename, TRUE, NULL);
@@ -1107,7 +1179,7 @@ static gboolean delete_files (iTunesDB *itdb)
 		  g_cond_timed_wait (cond, mutex, &gtime);
 	      } while(!mutex_data);
 	      g_mutex_unlock (mutex);
-	      rmres = (gint)g_thread_join (thread);
+	      rmres = GPOINTER_TO_UINT(g_thread_join (thread));
 	      if (rmres == -1) result = FALSE;
 	  }
 	  else {
@@ -1145,11 +1217,10 @@ static gboolean flush_tracks (iTunesDB *itdb)
   GList *gl;
   gint count, n;
   gchar *buf;
-  Track  *track;
   gboolean result = TRUE;
   static gboolean abort_flag;
   GtkWidget *dialog, *progress_bar;
-  time_t diff, start, fullsecs, hrs, mins, secs;
+  time_t start;
   gchar *progtext = NULL;
   ExtraiTunesDBData *eitdb;
 #ifdef G_THREADS_ENABLED
@@ -1182,7 +1253,8 @@ static gboolean flush_tracks (iTunesDB *itdb)
 
   for (gl=itdb->tracks; gl && !abort_flag; gl=gl->next)
   {
-      track = gl->data;
+      time_t diff, fullsecs, hrs, mins, secs;
+      Track *track = gl->data;
       g_return_val_if_fail (track, FALSE); /* this will hang the
 					      application :-( */
       if (!track->transferred)             /* but this would crash
@@ -1371,11 +1443,12 @@ gboolean gp_write_itdb (iTunesDB *itdb)
   while (widgets_blocked && gtk_events_pending ())
       gtk_main_iteration ();
 
+
   if (success && !prefs_get_offline () &&
       (itdb->usertype & GP_ITDB_TYPE_IPOD))
   {   /* write to the iPod */
       GError *error = NULL;
-      if (!itdb_write (itdb, NULL, &error))
+      if (!itdb_write (itdb, &error))
       {   /* an error occured */
 	  success = FALSE;
 	  if (error && error->message)
@@ -1385,9 +1458,10 @@ gboolean gp_write_itdb (iTunesDB *itdb)
 	  g_error_free (error);
 	  error = NULL;
       }
+
       if (success)
       {   /* write shuffle data */
-	  if (!itdb_shuffle_write (itdb, NULL, &error))
+	  if (!itdb_shuffle_write (itdb, &error))
 	  {   /* an error occured */
 	      success = FALSE;
 	      if (error && error->message)
@@ -1539,7 +1613,18 @@ void handle_export (void)
 	eitdb = itdb->userdata;
 	g_return_if_fail (eitdb);
 	if (eitdb->data_changed || eitdb->itdb_imported)
+	{
+	    Playlist *pl;
+	    /* update smart playlists before writing */
+	    itdb_spl_update_live (itdb);
+	    pl = pm_get_selected_playlist ();
+	    if (pl && (pl->itdb == itdb) &&
+		pl->is_spl && pl->splpref.liveupdate)
+	    {   /* Update display if necessary */
+		st_redisplay (0);
+	    }
 	    success &= gp_write_itdb (itdb);
+	}
     }
 
     if (prefs_get_concal_autosync ())
@@ -1627,8 +1712,7 @@ void gp_itdb_set_mountpoint (const gchar *mp)
 	    prefs_set_string_value (pmp, mp);
 	    g_free (pmp);
 	    /* store to itdb */
-	    g_free (itdb->mountpoint);
-	    itdb->mountpoint = g_strdup (mp);
+	    itdb_set_mountpoint (itdb, mp);
 	}
 	++i;
     }
