@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-05 22:40:10 jcs>
+/* Time-stamp: <2005-12-04 17:02:33 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users.sourceforge.net>
 |  Part of the gtkpod project.
@@ -23,7 +23,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: fileselection.c,v 1.2 2005/06/05 14:48:37 jcsjcs Exp $
+|  $Id: fileselection.c,v 1.4 2005/12/04 10:24:38 jcsjcs Exp $
 */
 
 /***********************************************************************
@@ -254,6 +254,59 @@ void create_add_playlists_dialog(void)
 
 
 
+
+/* 
+ * Add Cover Art
+ */
+gchar *fileselection_get_cover_filename (void)
+{
+    GtkWidget* fc;  /* The file chooser dialog */
+    gint response;  /* The response of the filechooser */
+    gchar *filename = NULL; /* The chosen file */
+    const gchar *dir1;
+    gchar *dir2;
+
+    /* Create the file chooser, and handle the response */
+    fc = gtk_file_chooser_dialog_new (_("Set Cover"),
+				      NULL,
+				      GTK_FILE_CHOOSER_ACTION_OPEN,
+				      GTK_STOCK_CANCEL,
+				      GTK_RESPONSE_CANCEL,
+				      GTK_STOCK_OPEN,
+				      GTK_RESPONSE_ACCEPT,
+				      NULL);
+
+    gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (fc), FALSE);
+
+    dir1 = prefs_get_last_dir_browse ();
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (fc), dir1);
+
+    response = gtk_dialog_run(GTK_DIALOG(fc));
+
+    switch (response)
+    {
+    case GTK_RESPONSE_ACCEPT:
+	dir2 = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (fc));
+	prefs_set_last_dir_browse (dir2);
+	g_free (dir2);
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (fc));
+	break;
+    case GTK_RESPONSE_CANCEL:
+	break;
+    default:	/* Fall through */
+	break;
+    }		
+    gtk_widget_destroy(fc);
+    return filename;
+}
+
+
+
+
+
+
+
+
 /*
 |  Changed by Jorg Schuler <jcsjcs at users.sourceforge.net> to compile
 |  "standalone" with the gtkpod project 2002/11/24
