@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-17 22:12:15 jcs>
+/* Time-stamp: <2005-11-25 23:52:11 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_input.c,v 1.11 2005/06/17 13:30:04 jcsjcs Exp $
+|  $Id: misc_input.c,v 1.12 2005/11/26 13:44:41 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -264,7 +264,7 @@ static GList *add_blocked_widget (GList *blocked_widgets, gchar *name)
     GtkWidget *w;
     struct blocked_widget *bw;
 
-    if((w = glade_xml_get_widget (main_window_xml,  name)))
+    if((w = gtkpod_xml_get_widget (main_window_xml,  name)))
     {
 	bw = g_malloc0 (sizeof (struct blocked_widget));
 	bw->widget = w;
