@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-20 23:08:22 jcs>
+/* Time-stamp: <2005-12-11 02:00:14 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: misc_track.c,v 1.21 2005/06/20 14:32:06 jcsjcs Exp $
+|  $Id: misc_track.c,v 1.33 2005/12/10 17:04:29 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -39,6 +39,7 @@
 #include "info.h"
 #include "charset.h"
 #include <math.h>
+#include <stdlib.h>
 #include <string.h>
 
 
@@ -270,8 +271,8 @@ void gp_duplicate_remove (Track *oldtrack, Track *track)
        /* Set rating */
        if (oldtrack->rating && track->rating)
 	   oldtrack->rating =
-	       floor((double)(oldtrack->rating + track->rating + RATING_STEP) /
-		     (2 * RATING_STEP)) * RATING_STEP;
+	       floor((double)(oldtrack->rating + track->rating + ITDB_RATING_STEP) /
+		     (2 * ITDB_RATING_STEP)) * ITDB_RATING_STEP;
        else
 	   oldtrack->rating = MAX (oldtrack->rating, track->rating);
        /* Set 'modified' timestamp */
@@ -413,7 +414,7 @@ Track *gp_track_by_filename (iTunesDB *itdb, gchar *filename)
 	    gchar *ipod_path;
 	    g_return_val_if_fail (track, NULL);
 	    mount = charset_from_utf8 (prefs_get_ipod_mount ());
-	    ipod_path = itdb_filename_on_ipod (mount, track);
+	    ipod_path = itdb_filename_on_ipod (track);
 	    g_free (mount);
 	    if (ipod_path)
 	    {
@@ -485,27 +486,71 @@ gchar **track_get_item_pointer (Track *track, T_item t_item)
     case T_COMPOSER:
 	result = &track->composer;
 	break;
-    case T_FDESC:
-	result = &track->fdesc;
-	break;
-    case T_GROUPING:
-	result = &track->grouping;
+    case T_FILETYPE:
+	result = &track->filetype;
 	break;
     case T_IPOD_PATH:
 	result = &track->ipod_path;
 	break;
+    case T_PC_PATH:
+	result = &etr->pc_path_utf8;
+	break;
     case T_YEAR:
 	result = &etr->year_str;
 	break;
-    default:
+    case T_GROUPING:
+	result = &track->grouping;
+	break;
+    case T_CATEGORY:
+	result = &track->category;
+	break;
+    case T_DESCRIPTION:
+	result = &track->description;
+	break;
+    case T_PODCASTURL:
+	result = &track->podcasturl;
+	break;
+    case T_PODCASTRSS:
+	result = &track->podcastrss;
+	break;
+    case T_SUBTITLE:
+	result = &track->subtitle;
+	break;
+    case T_ALL:
+    case T_IPOD_ID:
+    case T_TRACK_NR:
+    case T_TRANSFERRED:
+    case T_SIZE:
+    case T_TRACKLEN:
+    case T_BITRATE:
+    case T_SAMPLERATE:
+    case T_BPM:
+    case T_PLAYCOUNT:
+    case T_RATING:
+    case T_TIME_ADDED:
+    case T_TIME_PLAYED:
+    case T_TIME_MODIFIED:
+    case T_TIME_RELEASED:
+    case T_VOLUME:
+    case T_SOUNDCHECK:
+    case T_CD_NR:
+    case T_COMPILATION:
+    case T_CHECKED:
+    case T_ITEM_NUM:
 	g_return_val_if_reached (NULL);
     }
     return result;
 }
 
+
+
+
+
+
+
 /* return the UTF8 item @t_item. @t_item is one of
    (the applicable) T_* defined in track.h */
-gchar *track_get_item (Track *track, T_item t_item)
+const gchar *track_get_item (Track *track, T_item t_item)
 {
     gchar **ptr;
 
@@ -518,6 +563,187 @@ gchar *track_get_item (Track *track, T_item t_item)
 }
 
 
+/* Copy item @item from @frtrack to @totrack.
+   Return value:
+     TRUE: @totrack was changed
+     FALSE: @totrack is unchanged
+*/
+gboolean track_copy_item (Track *frtrack, Track *totrack, T_item item)
+{
+    gboolean changed = FALSE;
+    const gchar *fritem;
+    gchar **toitem_ptr;
+
+    g_return_val_if_fail (frtrack, FALSE);
+    g_return_val_if_fail (totrack, FALSE);
+    g_return_val_if_fail ((item > 0) && (item < T_ITEM_NUM), FALSE);
+
+    if (frtrack == totrack) return FALSE;
+
+    switch (item)
+    {
+    case T_ALBUM:
+    case T_ARTIST:
+    case T_TITLE:
+    case T_GENRE:
+    case T_COMMENT:
+    case T_COMPOSER:
+    case T_FILETYPE:
+    case T_IPOD_PATH:
+    case T_PC_PATH:
+    case T_YEAR:
+    case T_GROUPING:
+    case T_CATEGORY:
+    case T_DESCRIPTION:
+    case T_PODCASTURL:
+    case T_PODCASTRSS:
+    case T_SUBTITLE:
+	fritem = track_get_item (frtrack, item);
+	toitem_ptr = track_get_item_pointer (totrack, item);
+	g_return_val_if_fail (fritem, FALSE);
+	g_return_val_if_fail (toitem_ptr, FALSE);
+	if ((*toitem_ptr == NULL) || (strcmp (fritem, *toitem_ptr) != 0))
+	{
+	    g_free (*toitem_ptr);
+	    *toitem_ptr = g_strdup (fritem);
+	    changed = TRUE;
+	}
+	break;
+    case T_IPOD_ID:
+	if (frtrack->id != totrack->id)
+	{
+	    totrack->id = frtrack->id;
+	    changed = TRUE;
+	}
+	break;
+    case T_TRACK_NR:
+	if (frtrack->track_nr != totrack->track_nr)
+	{
+	    totrack->track_nr = frtrack->track_nr;
+	    changed = TRUE;
+	}
+	if (frtrack->tracks != totrack->tracks)
+	{
+	    totrack->tracks = frtrack->tracks;
+	    changed = TRUE;
+	}
+	break;
+    case T_TRANSFERRED:
+	if (frtrack->transferred != totrack->transferred)
+	{
+	    totrack->transferred = frtrack->transferred;
+	    changed = TRUE;
+	}
+	break;
+    case T_SIZE:
+	if (frtrack->size != totrack->size)
+	{
+	    totrack->size = frtrack->size;
+	    changed = TRUE;
+	}
+	break;
+    case T_TRACKLEN:
+	if (frtrack->tracklen != totrack->tracklen)
+	{
+	    totrack->tracklen = frtrack->tracklen;
+	    changed = TRUE;
+	}
+	break;
+    case T_BITRATE:
+	if (frtrack->bitrate != totrack->bitrate)
+	{
+	    totrack->bitrate = frtrack->bitrate;
+	    changed = TRUE;
+	}
+	break;
+    case T_SAMPLERATE:
+	if (frtrack->samplerate != totrack->samplerate)
+	{
+	    totrack->samplerate = frtrack->samplerate;
+	    changed = TRUE;
+	}
+	break;
+    case T_BPM:
+	if (frtrack->BPM != totrack->BPM)
+	{
+	    totrack->BPM = frtrack->BPM;
+	    changed = TRUE;
+	}
+	break;
+    case T_PLAYCOUNT:
+	if (frtrack->playcount != totrack->playcount)
+	{
+	    totrack->playcount = frtrack->playcount;
+	    changed = TRUE;
+	}
+	break;
+    case T_RATING:
+	if (frtrack->rating != totrack->rating)
+	{
+	    totrack->rating = frtrack->rating;
+	    changed = TRUE;
+	}
+	break;
+    case T_TIME_ADDED:
+    case T_TIME_PLAYED:
+    case T_TIME_MODIFIED:
+    case T_TIME_RELEASED:
+	if (time_get_time (frtrack, item) !=
+	    time_get_time (totrack, item))
+	{
+	    time_set_time (totrack, time_get_time (frtrack, item), item);
+	    changed = TRUE;
+	}
+	break;
+    case T_VOLUME:
+	if (frtrack->volume != totrack->volume)
+	{
+	    totrack->volume = frtrack->volume;
+	    changed = TRUE;
+	}
+	break;
+    case T_SOUNDCHECK:
+	if (frtrack->soundcheck != totrack->soundcheck)
+	{
+	    totrack->soundcheck = frtrack->soundcheck;
+	    changed = TRUE;
+	}
+	break;
+    case T_CD_NR:
+	if (frtrack->cd_nr != totrack->cd_nr)
+	{
+	    totrack->cd_nr = frtrack->cd_nr;
+	    changed = TRUE;
+	}
+	if (frtrack->cds != totrack->cds)
+	{
+	    totrack->cds = frtrack->cds;
+	    changed = TRUE;
+	}
+	break;
+    case T_COMPILATION:
+	if (frtrack->compilation != totrack->compilation)
+	{
+	    totrack->compilation = frtrack->compilation;
+	    changed = TRUE;
+	}
+	break;
+    case T_CHECKED:
+	if (frtrack->checked != totrack->checked)
+	{
+	    totrack->checked = frtrack->checked;
+	    changed = TRUE;
+	}
+	break;
+    case T_ITEM_NUM:
+    case T_ALL:
+	g_return_val_if_reached (FALSE);
+
+    }	
+    return changed;
+}
+
+
 /* return a pointer to the specified timestamp. @t_item is one of (the
    applicable) T_* defined in track.h.  If the parameters are illegal,
    "0" is returned. */
@@ -531,6 +757,8 @@ guint32 *track_get_timestamp_ptr (Track *track, T_item t_item)
 	return &track->time_played;
     case T_TIME_MODIFIED:
 	return &track->time_modified;
+    case T_TIME_RELEASED:
+	return &track->time_released;
     case T_TIME_ADDED:
 	return &track->time_added;
     default:
@@ -544,14 +772,327 @@ guint32 *track_get_timestamp_ptr (Track *track, T_item t_item)
    illegal, "0" is returned. */
 guint32 track_get_timestamp (Track *track, T_item t_item)
 {
+    guint32 *ptr;
     g_return_val_if_fail (track, 0);
 
-    guint32 *ptr = track_get_timestamp_ptr (track, t_item);
+    ptr = track_get_timestamp_ptr (track, t_item);
     if (ptr)  return *ptr;
     else      return 0;
 }
 
 
+/* Return text for display. g_free() after use. */
+gchar *track_get_text (Track *track, T_item item)
+{
+    gchar *text = NULL;
+    ExtraTrackData *etr;
+    iTunesDB *itdb;
+
+    g_return_val_if_fail ((item > 0) && (item < T_ITEM_NUM), NULL);
+    g_return_val_if_fail (track, NULL);
+    etr = track->userdata;
+    g_return_val_if_fail (etr, NULL);
+    itdb = track->itdb;
+    g_return_val_if_fail (itdb, NULL);
+
+    switch (item)
+    {
+    case T_TITLE:
+    case T_ARTIST:
+    case T_ALBUM:
+    case T_GENRE:
+    case T_COMPOSER:
+    case T_COMMENT:
+    case T_FILETYPE:
+    case T_GROUPING:
+    case T_CATEGORY:
+    case T_DESCRIPTION:
+    case T_PODCASTURL:
+    case T_PODCASTRSS:
+    case T_SUBTITLE:
+	text = g_strdup (track_get_item (track, item));
+	break;
+    case T_TRACK_NR:
+	if (track->tracks == 0)
+	    text = g_strdup_printf ("%d", track->track_nr);
+	else
+	    text = g_strdup_printf ("%d/%d",
+				    track->track_nr, track->tracks);
+	break;
+    case T_CD_NR:
+	if (track->cds == 0)
+	    text = g_strdup_printf ("%d", track->cd_nr);
+	else
+	    text = g_strdup_printf ("%d/%d", track->cd_nr, track->cds);
+	break;
+    case T_IPOD_ID:
+	if (track->id != -1)
+	    text = g_strdup_printf ("%d", track->id);
+	else
+	    text = g_strdup ("--");
+	break;
+    case T_PC_PATH:
+	text = g_strdup (etr->pc_path_utf8);
+	break;
+    case T_IPOD_PATH:
+	if (itdb->usertype & GP_ITDB_TYPE_IPOD)
+	{
+	    text = g_strdup (track->ipod_path);
+	}
+	if (itdb->usertype & GP_ITDB_TYPE_LOCAL)
+	{
+	    text = g_strdup (_("Local Database"));
+	}
+	break;
+    case T_SIZE:
+	text = g_strdup_printf ("%d", track->size);
+	break;
+    case T_TRACKLEN:
+	text = g_strdup_printf ("%d:%02d",
+				track->tracklen/60000,
+				(track->tracklen/1000)%60);
+	break;
+    case T_BITRATE:
+	text = g_strdup_printf ("%dk", track->bitrate);
+	break;
+    case T_SAMPLERATE:
+	text = g_strdup_printf ("%d", track->samplerate);
+	break;
+    case T_BPM:
+	text = g_strdup_printf ("%d", track->BPM);
+	break;
+    case T_PLAYCOUNT:
+	text = g_strdup_printf ("%d", track->playcount);
+	break;
+    case T_YEAR:
+	text = g_strdup_printf ("%d", track->year);
+	break;
+    case T_RATING:
+	text = g_strdup_printf ("%d", track->rating/ITDB_RATING_STEP);
+	break;
+    case T_TIME_PLAYED:
+    case T_TIME_MODIFIED:
+    case T_TIME_ADDED:
+    case T_TIME_RELEASED:
+	text = time_field_to_string (track, item);
+	break;
+    case T_VOLUME:
+	text = g_strdup_printf ("%d", track->volume);
+	break;
+    case T_SOUNDCHECK:
+	text = g_strdup_printf ("%0.2f", soundcheck_to_replaygain (track->soundcheck));
+	break;
+    case T_TRANSFERRED:
+    case T_COMPILATION:
+    case T_ALL:
+    case T_CHECKED:
+    case T_ITEM_NUM:
+	break;
+    }
+    return text;
+}
+
+
+
+/* Set track data according to @new_text
+
+   Return value: TRUE, if the track data was modified, FALSE otherwise
+*/
+gboolean track_set_text (Track *track, const gchar *new_text, T_item item)
+{
+    gboolean changed = FALSE;
+    gchar **itemp_utf8;
+    const gchar *str;
+    ExtraTrackData *etr;
+    gint32 nr;
+    time_t t;
+
+    g_return_val_if_fail (track, FALSE);
+    g_return_val_if_fail (new_text, FALSE);
+
+    etr = track->userdata;
+    g_return_val_if_fail (etr, FALSE);
+
+
+    switch(item)
+    {
+    case T_TITLE:
+    case T_ALBUM:
+    case T_ARTIST:
+    case T_GENRE:
+    case T_COMPOSER:
+    case T_COMMENT:
+    case T_FILETYPE:
+    case T_GROUPING:
+    case T_CATEGORY:
+    case T_DESCRIPTION:
+    case T_PODCASTURL:
+    case T_PODCASTRSS:
+    case T_SUBTITLE:
+        itemp_utf8 = track_get_item_pointer (track, item);
+        if (g_utf8_collate (*itemp_utf8, new_text) != 0)
+        {
+	    g_free (*itemp_utf8);
+	    *itemp_utf8 = g_strdup (new_text);
+	    changed = TRUE;
+        }
+        break;
+    case T_TRACK_NR:
+        nr = atoi (new_text);
+        if ((nr >= 0) && (nr != track->track_nr))
+        {
+	    track->track_nr = nr;
+	    changed = TRUE;
+        }
+	str = strrchr (new_text, '/');
+	if (str)
+	{
+	    nr = atoi (str+1);
+	    if ((nr >= 0) && (nr != track->tracks))
+	    {
+		track->tracks = nr;
+		changed = TRUE;
+	    }
+	}
+        break;
+    case T_CD_NR:
+        nr = atoi (new_text);
+        if ((nr >= 0) && (nr != track->cd_nr))
+        {
+	    track->cd_nr = nr;
+	    changed = TRUE;
+        }
+	str = strrchr (new_text, '/');
+	if (str)
+	{
+	    nr = atoi (str+1);
+	    if ((nr >= 0) && (nr != track->cds))
+	    {
+		track->cds = nr;
+		changed = TRUE;
+	    }
+	}
+        break;
+    case T_YEAR:
+        nr = atoi (new_text);
+        if ((nr >= 0) && (nr != track->year))
+        {
+	    g_free (etr->year_str);
+	    etr->year_str = g_strdup_printf ("%d", nr);
+	    track->year = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_PLAYCOUNT:
+        nr = atoi (new_text);
+        if ((nr >= 0) && (nr != track->playcount))
+        {
+	    track->playcount = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_RATING:
+        nr = atoi (new_text);
+        if ((nr >= 0) && (nr <= 5) && (nr != track->rating))
+        {
+	    track->rating = nr*ITDB_RATING_STEP;
+	    changed = TRUE;
+        }
+        break;
+    case T_TIME_ADDED:
+    case T_TIME_PLAYED:
+    case T_TIME_MODIFIED:
+    case T_TIME_RELEASED:
+	t = time_string_to_time (new_text);
+	if ((t != -1) && (t != time_get_time (track, item)))
+	{
+	    time_set_time (track, t, item);
+	    changed = TRUE;
+	}
+	break;
+    case T_VOLUME:
+        nr = atoi (new_text);
+        if (nr != track->volume)
+        {
+	    track->volume = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_SOUNDCHECK:
+	nr = replaygain_to_soundcheck (atof (new_text));
+/* 	printf("%d : %f\n", nr, atof (new_text)); */
+        if (nr != track->soundcheck)
+        {
+	    track->soundcheck = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_SIZE:
+        nr = atoi (new_text);
+        if (nr != track->size)
+        {
+	    track->size = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_BITRATE:
+        nr = atoi (new_text);
+        if (nr != track->bitrate)
+        {
+	    track->bitrate = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_SAMPLERATE:
+        nr = atoi (new_text);
+        if (nr != track->samplerate)
+        {
+	    track->samplerate = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_BPM:
+        nr = atoi (new_text);
+        if (nr != track->BPM)
+        {
+	    track->BPM = nr;
+	    changed = TRUE;
+        }
+        break;
+    case T_TRACKLEN:
+	str = strrchr (new_text, ':');
+	if (str)
+	{   /* MM:SS */
+	    nr = 1000 * (60 * atoi (new_text) + atoi (str+1));
+	}
+	else
+	{   /* SS */
+	    nr = 1000 * atoi (new_text);
+	}
+	if (nr != track->tracklen)
+	{
+	    track->tracklen = nr;
+	    changed = TRUE;
+	}
+	break;
+    case T_PC_PATH:
+    case T_IPOD_PATH:
+    case T_IPOD_ID:
+    case T_TRANSFERRED:
+    case T_COMPILATION:
+    case T_CHECKED:
+    case T_ALL:
+    case T_ITEM_NUM:
+	gtkpod_warning ("Programming error: track_set_text() called with illegal argument (item: %d)\n", item);
+	break;
+    }
+
+    return changed;
+}
+
+
+
+
 /* Fills @size with the size and @num with the number of
    non-transferred tracks. The size is in Bytes, minus the space taken
    by tracks that will be overwritten. */
@@ -607,10 +1148,31 @@ static void add_tracks_to_playlist (Playlist *pl,
 /* 	    printf ("add tr %p to pl: %p\n", track, pl); */
 	    if (from_itdb == to_itdb)
 	    {   /* DND within the same itdb */
-		if (pl->type == ITDB_PL_TYPE_NORM)
-		{   /* not necessary to add to MPL as track has to be
-		     * present already */
-		    gp_playlist_add_track (pl, track, TRUE);
+
+		/* set flags to 'podcast' if adding to podcast list */
+		if (itdb_playlist_is_podcasts (pl))
+		    gp_track_set_flags_podcast (track);
+
+		if (!itdb_playlist_contains_track (to_mpl, track))
+		{   /* add to MPL if not already present (will happen
+		     * if dragged from the podcasts playlist */
+		    gp_playlist_add_track (to_mpl, track, TRUE);
+		}
+		if (!itdb_playlist_is_mpl (pl))
+		{
+		    /* add to designated playlist -- unless adding
+		     * to podcasts list and track already exists there */
+		    if (itdb_playlist_is_podcasts (pl) &&
+			g_list_find (pl->members, track))
+		    {
+			gchar *buf = get_track_info (track, FALSE);
+			gtkpod_warning (_("Podcast already present: '%s'\n\n"), buf);
+			g_free (buf);
+		    }
+		    else
+		    {
+			gp_playlist_add_track (pl, track, TRUE);
+		    }
 		}
 	    }
 	    else
@@ -623,14 +1185,50 @@ static void add_tracks_to_playlist (Playlist *pl,
 		   same track already exists in the database, the already
 		   existing track is returned and @duptr is freed */
 		addtr = gp_track_add (to_itdb, duptr);
-		/* check if we need to add to the MPL */
+
+		/* set flags to 'podcast' if adding to podcast list */
+		if (itdb_playlist_is_podcasts (pl))
+		    gp_track_set_flags_podcast (addtr);
+
 		if (addtr == duptr)
-		{
-		    itdb_playlist_add_track (to_mpl, addtr, -1);
+		{   /* no duplicate */
+		    /* we need to add to the MPL if the track is no
+		       duplicate and will not be added to the podcasts
+		       playlist */
+		    if (!itdb_playlist_is_podcasts (pl))
+		    {   /* don't add to mpl if we add to the podcasts
+			   playlist */
+			gp_playlist_add_track (to_mpl, addtr, TRUE);
+		    }
 		}
-		if (pl->type == ITDB_PL_TYPE_NORM)
+		else
+		{   /* duplicate */
+		    /* we also need to add to the MPL if the track is a
+		       duplicate, does not yet exist in the MPL and will
+		       not be added to a podcast list (this happens if
+		       it's already in the podcast list) */
+		    if ((!itdb_playlist_contains_track (to_mpl, addtr)) &&
+			(!itdb_playlist_is_podcasts (pl)))
+		    {
+			gp_playlist_add_track (to_mpl, addtr, TRUE);
+		    }
+		}
+		/* add to designated playlist (if not mpl) -- unless
+		 * adding to podcasts list and track already * exists
+		 * there */
+		if (!itdb_playlist_is_mpl (pl))
 		{
-		    gp_playlist_add_track (pl, addtr, TRUE);
+		    if (itdb_playlist_is_podcasts (pl) &&
+			g_list_find (pl->members, addtr))
+		    {
+			gchar *buf = get_track_info (addtr, FALSE);
+			gtkpod_warning (_("Podcast already present: '%s'\n\n"), buf);
+			g_free (buf);
+		    }
+		    else
+		    {
+			gp_playlist_add_track (pl, addtr, TRUE);
+		    }
 		}
 	    }
 	}
@@ -755,7 +1353,7 @@ Playlist *add_text_plain_to_playlist (iTunesDB *itdb, Playlist *pl,
 		}
 		if (g_file_test (decoded_file, G_FILE_TEST_IS_REGULAR))
 		{   /* regular file */
-		    gint ftype = determine_file_type (decoded_file);
+		    FileType ftype = determine_file_type (decoded_file);
 		    switch (ftype)
 		    {
 		    case FILE_TYPE_MP3:
@@ -763,6 +1361,10 @@ Playlist *add_text_plain_to_playlist (iTunesDB *itdb, Playlist *pl,
 		    case FILE_TYPE_M4P:
 		    case FILE_TYPE_M4B:
 		    case FILE_TYPE_WAV:
+		    case FILE_TYPE_M4V:
+		    case FILE_TYPE_MP4:
+		    case FILE_TYPE_MOV:
+		    case FILE_TYPE_MPG:
 			if (!pl)
 			{  /* no playlist yet -- create new one */
 			    pl = add_new_pl_user_name (itdb, NULL,
@@ -782,6 +1384,7 @@ Playlist *add_text_plain_to_playlist (iTunesDB *itdb, Playlist *pl,
 			added = TRUE;
 			break;
 		    case FILE_TYPE_UNKNOWN:
+		    case FILE_TYPE_IMAGE:
 			break;
 		    }
 		}
@@ -810,6 +1413,33 @@ Playlist *add_text_plain_to_playlist (iTunesDB *itdb, Playlist *pl,
     return NULL;
 }
 
+/*------------------------------------------------------------------*\
+ *                                                                  *
+ * Functions setting default values on tracks                       *
+ *                                                                  *
+\*------------------------------------------------------------------*/
+
+/* set podcast-specific flags for @track */
+void gp_track_set_flags_podcast (Track *track)
+{
+    g_return_if_fail (track);
+    track->flag1 = 0x02;  /* unknown */
+    track->flag2 = 0x01;  /* skip when shuffling */
+    track->flag3 = 0x01;  /* remember playback position */
+    track->flag4 = 0x01;  /* Show Title/Album on the 'Now Playing' page */
+}
+
+/* set podcast-specific flags for @track */
+void gp_track_set_flags_default (Track *track)
+{
+    g_return_if_fail (track);
+    track->flag1 = 0x02;  /* unknown */
+    track->flag2 = 0x00;  /* do not skip when shuffling */
+    track->flag3 = 0x00;  /* do not remember playback position */
+    track->flag4 = 0x00;  /* Show Title/Album/Artist on the 'Now
+			     Playing' page */
+}
+
 
 /*------------------------------------------------------------------*\
  *                                                                  *
