@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-17 22:12:13 jcs>
+/* Time-stamp: <2005-11-23 02:36:10 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: mp3file.c,v 1.54 2005/06/17 13:30:04 jcsjcs Exp $
+|  $Id: mp3file.c,v 1.58 2005/11/23 04:16:12 jcsjcs Exp $
 */
 
 /* The code in the first section of this file is taken from the
@@ -63,6 +63,12 @@ struct _File_Tag
     /* CD/disc number handling */
     gchar *cdnostring;    /* Position of disc in the album */
     gchar *cdno_total;    /* The number of discs in the album (ex: 1/2) */
+    gchar *compilation;   /* The track is a member of a compilation */
+    gchar *podcasturl;    /* The following are mainly used for podcasts */
+    gchar *description;
+    gchar *podcastrss;
+    gchar *time_released;
+    gchar *subtitle;
 };
 
 /* This code is taken from the mp3info code. Only the code needed for
@@ -928,40 +934,60 @@ static guint get_track_time (gchar *path)
 #include <id3tag.h>
 #include "prefs.h"
 
+#ifndef ID3_FRAME_GROUP
+#define ID3_FRAME_GROUP "TPE2"
+#endif
+
+
 
 static gchar* id3_get_string (struct id3_tag *tag, char *frame_name)
 {
-    const id3_ucs4_t *string;
+    const id3_ucs4_t *string = NULL;
+    const id3_byte_t *binary = NULL;
+    id3_length_t len = 0;
     struct id3_frame *frame;
     union id3_field *field;
     gchar *utf8 = NULL;
     enum id3_field_textencoding encoding = ID3_FIELD_TEXTENCODING_ISO_8859_1;
 
     frame = id3_tag_findframe (tag, frame_name, 0);
+/*     printf ("frame: %p\n", frame); */
+
     if (!frame) return NULL;
 
     /* Find the encoding used for the field */
     field = id3_frame_field (frame, 0);
 /*     printf ("field: %p\n", field); */
+
     if (field && (id3_field_type (field) == ID3_FIELD_TYPE_TEXTENCODING))
     {
 	encoding = field->number.value;
 /*	printf ("encoding: %d\n", encoding); */
     }
 
-    if (frame_name == ID3_FRAME_COMMENT)
-	field = id3_frame_field (frame, 3);
-    else
-	field = id3_frame_field (frame, 1);
+    /* The last field contains the data */
+    field = id3_frame_field (frame, frame->nfields-1);
 
 /*     printf ("field: %p\n", field); */
 
     if (!field) return NULL;
 
-    if (frame_name == ID3_FRAME_COMMENT)
-	string = id3_field_getfullstring (field);
-    else
+    switch (field->type)
+    {
+    case ID3_FIELD_TYPE_STRINGLIST:
 	string = id3_field_getstrings (field, 0);
+	break;
+    case ID3_FIELD_TYPE_STRINGFULL:
+	string = id3_field_getfullstring (field);
+	break;
+    case ID3_FIELD_TYPE_BINARYDATA:
+	binary = id3_field_getbinarydata(field, &len);
+	if (len > 0)
+	    return charset_to_utf8 (binary+1);
+	break;
+    default:
+	break;
+    }
 
 /*     printf ("string: %p\n", string); */
 
@@ -1122,12 +1148,24 @@ gboolean id3_tag_read (gchar *filename, File_Tag *tag)
     if ((id3tag = id3_file_tag(id3file)))
     {
 	tag->title = id3_get_string (id3tag, ID3_FRAME_TITLE);
-	tag->artist = id3_get_string (id3tag, ID3_FRAME_ARTIST);
+	tag->artist = id3_get_string (id3tag, ID3_FRAME_GROUP);
+	if (!tag->artist || !*tag->artist)
+	{
+	    g_free (tag->artist);
+	    tag->artist = id3_get_string (id3tag, ID3_FRAME_ARTIST);
+	}
 	tag->album = id3_get_string (id3tag, ID3_FRAME_ALBUM);
 	tag->year = id3_get_string (id3tag, ID3_FRAME_YEAR);
 	tag->composer = id3_get_string (id3tag, "TCOM");
 	tag->comment = id3_get_string (id3tag, ID3_FRAME_COMMENT);
 	tag->genre = id3_get_string (id3tag, ID3_FRAME_GENRE);
+	tag->compilation = id3_get_string (id3tag, "TCMP");
+	tag->subtitle = id3_get_string (id3tag, "TIT3");
+
+	tag->podcasturl = id3_get_string (id3tag, "YTID");
+	tag->podcastrss = id3_get_string (id3tag, "YWFD");
+	tag->description = id3_get_string (id3tag, "YTDS");
+	tag->time_released = id3_get_string (id3tag, "YTDR");
 
 	string = id3_get_string (id3tag, "TLEN");
 	if (string)
@@ -1206,6 +1244,34 @@ static enum id3_field_textencoding get_encoding (struct id3_tag *tag)
 }
 
 
+/* I'm not really sure about this: The original TAG identifier was
+   "TID", but no matter what I do I end up writing "YTID" */
+void set_uncommon_tag (struct id3_tag *id3tag,
+		       const gchar *id,
+		       const gchar *text,
+		       enum id3_field_textencoding encoding)
+{
+#if 0
+    struct id3_frame *frame;
+
+    frame = id3_tag_findframe (id3tag, id, 0);
+	union id3_field *field;
+	frame->flags = 0;
+	field = id3_frame_field (frame, 0);
+	    if (field)
+	    {
+		string1 = g_strdup_printf ("%c%s", '\0',
+					   track->podcasturl);
+		id3_field_setbinarydata (field, string1,
+					 strlen(track->podcasturl)+1);
+		g_free (string1);
+	    }
+
+#endif
+}
+
+
+
 /**
  * Write the ID3 tags to the file.
  * @returns: TRUE on success, else FALSE.
@@ -1255,6 +1321,12 @@ gboolean mp3_write_file_info (gchar *filename, Track *track)
 	id3_set_string (id3tag, ID3_FRAME_ALBUM, track->album, encoding);
 	id3_set_string (id3tag, ID3_FRAME_GENRE, track->genre, encoding);
 	id3_set_string (id3tag, ID3_FRAME_COMMENT, track->comment, encoding);
+	id3_set_string (id3tag, "TIT3", track->subtitle, encoding);
+
+	set_uncommon_tag (id3tag, "YTID", track->podcasturl, encoding);
+	set_uncommon_tag (id3tag, "YTDS", track->description, encoding);
+	set_uncommon_tag (id3tag, "YWFD", track->podcastrss, encoding);
+
 	id3_set_string (id3tag, "TCOM", track->composer, encoding);
 
 	if (track->tracks)
@@ -1272,6 +1344,10 @@ gboolean mp3_write_file_info (gchar *filename, Track *track)
 	    string1 = g_strdup_printf ("%d", track->cd_nr);
 	id3_set_string (id3tag, "TPOS", string1, encoding);
 	g_free(string1);
+        
+       string1 = g_strdup_printf ("%d", track->compilation);
+       id3_set_string (id3tag, "TCMP", string1, encoding);
+       g_free(string1);
     } 
 
     if (id3_file_update(id3file) != 0)
@@ -1349,7 +1425,10 @@ static gint lame_vcmp(gchar a[5], gchar b[5]) {
 }
 
 
-static void read_lame_replaygain(char buf[], Track *track, int gain_adjust) {
+/* buf[] must be declared unsigned -- otherwise the casts, shifts and
+   additions below produce funny results */             
+static void read_lame_replaygain(unsigned char buf[],
+				 Track *track, int gain_adjust) {
 	char oc, nc;
 	gint gain;
 	ExtraTrackData *etr;
@@ -1358,6 +1437,13 @@ static void read_lame_replaygain(char buf[], Track *track, int gain_adjust) {
 	etr = track->userdata;
 	g_return_if_fail (etr);
 
+	/* buf[0] and buf[1] are a bit field:
+	   3 bits: name  (mask: 0xe0 = 11100000)
+	   3 bits: originator (mask: 0x1c = 00011100)
+	   1 bit: negative if set (mask: 0x02 = 00000010)
+	   9 bits: value
+	*/
+
 	/* check originator */
 	oc = (buf[0] & 0x1c) >> 2;
 	if ((oc <= 0) || (oc > 3)) return;
@@ -1366,7 +1452,7 @@ static void read_lame_replaygain(char buf[], Track *track, int gain_adjust) {
 	nc = buf[0] & 0xe0;
 	if (!((nc == 0x20) || (nc == 0x40))) return;
 	
-	gain = ((buf[0] & 0x1) << 8) + buf[1];
+	gain = ((((guint)buf[0]) & 0x1) << 8) + buf[1];
 	
 	/* This would be a value of -0.
 	 * That value however is illegal by current standards and reserved for
@@ -1955,7 +2041,7 @@ Track *mp3_get_file_info (gchar *name)
     track = gp_track_new ();
     if (prefs_get_readtags() && (id3_tag_read (name, &filetag) == TRUE))
     {
-	track->fdesc = g_strdup ("MPEG audio file");
+	track->filetype = g_strdup ("MPEG audio file");
 
 	if (filetag.album)
 	{
@@ -1986,6 +2072,27 @@ Track *mp3_get_file_info (gchar *name)
 	{
 	    track->comment = filetag.comment;
 	}
+
+	if (filetag.podcasturl)
+	{
+	    track->podcasturl = filetag.podcasturl;
+	}
+
+	if (filetag.podcastrss)
+	{
+	    track->podcastrss = filetag.podcastrss;
+	}
+
+	if (filetag.subtitle)
+	{
+	    track->subtitle = filetag.subtitle;
+	}
+
+	if (filetag.description)
+	{
+	    track->description = filetag.description;
+	}
+
 	if (filetag.year == NULL)
 	{
 	    track->year = 0;
@@ -2035,6 +2142,16 @@ Track *mp3_get_file_info (gchar *name)
 	    track->cds = atoi(filetag.cdno_total);
 	    g_free (filetag.cdno_total);
 	}
+
+	if (filetag.compilation == NULL)
+	{
+	    track->compilation = 0;
+	}
+	else
+	{
+	    track->compilation = atoi(filetag.compilation);
+	    g_free (filetag.compilation);
+	}
     }
 
     mp3_read_gain (name, track);
