@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-06-17 22:12:13 jcs>
+/* Time-stamp: <2005-11-22 22:34:20 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: mp4file.c,v 1.23 2005/06/17 13:30:04 jcsjcs Exp $
+|  $Id: mp4file.c,v 1.26 2005/11/30 14:21:37 jcsjcs Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -54,8 +54,15 @@
    gchar   *genre;            /+ genre (utf8)          +/
    gchar   *comment;          /+ comment (utf8)        +/
    gchar   *composer;         /+ Composer (utf8)       +/
-   gchar   *fdesc;            /+ Format description (utf8) +/
-   gchar   *charset;          /+ charset used for tags +/
+   gchar   *fdesc;            /+ Format description (utf8)   +/
+   gchar   *charset;          /+ charset used for tags       +/
+   gchar   *description;      /+ Description text (podcasts) +/
+   gchar   *podcasturl;       /+ URL/Title (podcasts)        +/
+   gchar   *podcastrss;       /+ Podcast RSS                 +/
+   gchar   *subtitle;         /+ Subtitle (podcasts)         +/
+   guint32 time_released;     /+ For podcasts: release date as
+				 displayed next to the title in the
+				 Podcast playlist  +/
    gint32  cd_nr;             /+ CD number             +/
    gint32  cds;               /+ number of CDs         +/
    gint32  track_nr;          /+ track number          +/
@@ -72,7 +79,7 @@
    gboolean peak_signal_set;  /+ has the peak signal been set?       +/
    gboolean radio_gain_set;   /+ has the radio gain been set?        +/
    gboolean audiophile_gain_set;/+ has the audiophile gain been set? +/
-
+   gboolean compilation;      /+ Track is part of a compilation CD   +/
 
    If prefs_get_tag_readtags() returns FALSE you only should fill in
    tracklen, bitrate and fdesc
@@ -152,7 +159,7 @@ Track *mp4_get_file_info (gchar *mp4FileName)
 
 	trackId = MP4FindTrackId(mp4File, 0, NULL, 0);
 	trackType = MP4GetTrackType(mp4File, trackId);
-	if (trackType && (strcmp(trackType, MP4_AUDIO_TRACK_TYPE) == 0))
+	if (trackType && ((strcmp(trackType, MP4_AUDIO_TRACK_TYPE) == 0) || (strcmp(trackType, MP4_VIDEO_TRACK_TYPE) == 0)))
 	{
 	    gchar *value;
 	    guint16 numvalue, numvalue2;
@@ -173,11 +180,13 @@ Track *mp4_get_file_info (gchar *mp4FileName)
 	    if (value)
 	    {
 		if (g_strcasecmp (value, ".m4a") == 0)
-		    track->fdesc = g_strdup ("AAC audio file");
+		    track->filetype = g_strdup ("AAC audio file");
 		if (g_strcasecmp (value, ".m4p") == 0)
-		    track->fdesc = g_strdup ("Protected AAC audio file");
+		    track->filetype = g_strdup ("Protected AAC audio file");
 		if (g_strcasecmp (value, ".m4b") == 0)
-		    track->fdesc = g_strdup ("AAC audio book file");
+		    track->filetype = g_strdup ("AAC audio book file");
+		if (g_strcasecmp (value, ".mp4") == 0)
+		    track->filetype = g_strdup ("MP4 video file");
 	    }
 	    if (prefs_get_readtags ())
 	    {
@@ -262,7 +271,7 @@ gboolean mp4_write_file_info (gchar *mp4FileName, Track *track)
 
 	trackId = MP4FindTrackId(mp4File, 0, NULL, 0);
 	trackType = MP4GetTrackType(mp4File, trackId);
-	if (trackType && (strcmp(trackType, MP4_AUDIO_TRACK_TYPE) == 0))
+	if (trackType && ((strcmp(trackType, MP4_AUDIO_TRACK_TYPE) == 0)||(strcmp(trackType, MP4_VIDEO_TRACK_TYPE) == 0)))
 	{
 	    gchar *value;
 
