@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-07-16 16:11:00 jcs>
+/* Time-stamp: <2005-12-14 23:13:45 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: prefs.c,v 1.146 2005/07/16 07:13:50 jcsjcs Exp $
+|  $Id: prefs.c,v 1.155 2005/12/10 17:04:29 jcsjcs Exp $
 */
 
 /* -------------------------------------------------------------------
@@ -102,6 +102,7 @@
 #include "misc.h"
 #include "misc_track.h"
 #include "prefs.h"
+#include "podcast.h"
 
 /* static function declarations */
 static void prefs_write_hash_values (FILE *fp);
@@ -140,23 +141,23 @@ struct cfg *cfg_new(void)
 {
     struct cfg *mycfg = NULL;
     gchar curdir[PATH_MAX], *str;
+    gchar *cfgdir;
     gint i;
 
+    cfgdir = prefs_get_cfgdir ();
+
     mycfg = g_malloc0 (sizeof (struct cfg));
     if(getcwd(curdir, PATH_MAX))
     {
-	mycfg->last_dir.browse = g_strdup_printf ("%s/", curdir);
+	mycfg->last_dir.browse = g_strdup (curdir);
     }
     else
     {
-	mycfg->last_dir.browse = g_strdup ("~/");
+	mycfg->last_dir.browse = convert_filename ("~/");
     }
     if((str = getenv("IPOD_MOUNTPOINT")))
     {
-	if (strncmp ("~/", str, 2) == 0)
-	    mycfg->ipod_mount = g_build_filename (g_get_home_dir(),
-						  str+2, NULL);
-	else mycfg->ipod_mount = g_strdup(str);
+	mycfg->ipod_mount = convert_filename (str);
     }
     else
     {
@@ -231,6 +232,8 @@ struct cfg *cfg_new(void)
     mycfg->parsetags = FALSE;
     mycfg->parsetags_overwrite = FALSE;
     mycfg->parsetags_template = g_strdup ("%a - %A/%T %t.mp3;%t.wav");
+    mycfg->coverart = TRUE;
+    mycfg->coverart_template = g_strdup ("%A;folder.jpg");
     for (i=0; i<PANED_NUM; ++i)
     {
 	mycfg->paned_pos[i] = -1;  /* -1 means: let gtk worry about position */
@@ -292,6 +295,22 @@ struct cfg *cfg_new(void)
     mycfg->mserv_report_probs = TRUE;
     mycfg->mserv_username = g_strdup ("");
 
+    mycfg->pc_dir = g_build_filename (cfgdir, "podcasts", NULL);
+    mycfg->pc_del_age = FALSE;
+    mycfg->pc_del_age_val = 1;
+    mycfg->pc_del_copied = FALSE;
+    mycfg->pc_auto_fetch = FALSE;
+    mycfg->pc_log = TRUE;
+    mycfg->pc_log_file = g_build_filename (cfgdir, "podcast.log", NULL);
+    mycfg->pc_auto_sync = FALSE;
+    mycfg->pc_ipod_del_age = FALSE;
+    mycfg->pc_ipod_del_age_val = 1;
+    mycfg->pc_ipod_del_played = FALSE;
+    mycfg->pc_ipod_inc_date = FALSE;
+    mycfg->pc_change_genre = FALSE;
+
+    g_free (cfgdir);
+
     return(mycfg);
 }
 
@@ -635,6 +654,14 @@ read_prefs_from_file_desc(FILE *fp)
 	  {
 	      prefs_set_parsetags_template(strdup(arg));
 	  }
+	  else if(g_ascii_strcasecmp (line, "coverart") == 0)
+	  {
+	      prefs_set_coverart((gboolean)atoi(arg));
+	  }
+	  else if(g_ascii_strcasecmp (line, "coverart_template") == 0)
+	  {
+	      prefs_set_coverart_template(strdup(arg));
+	  }
 	  else if(arg_comp (line, "col_visible", &off) == 0)
 	  {
 	      gint i = atoi (line+off);
@@ -658,6 +685,10 @@ read_prefs_from_file_desc(FILE *fp)
 	  {
 	      prefs_set_sort_tab_num(atoi(arg), FALSE);
 	  }
+	  else if(g_ascii_strcasecmp (line, "group_compilations") == 0)
+	  {
+	      prefs_set_group_compilations((gboolean)atoi(arg), FALSE);
+	  }
 	  else if(g_ascii_strcasecmp (line, "toolbar_style") == 0)
 	  {
 	      prefs_set_toolbar_style(atoi(arg));
@@ -899,6 +930,59 @@ read_prefs_from_file_desc(FILE *fp)
 	  {
 	      prefs_set_mserv_username (arg);
 	  }
+	  else if(g_ascii_strcasecmp (line, "pc_dir") == 0)
+	  {
+	      prefs_set_pc_dir (arg);
+	  }
+          else if(g_ascii_strcasecmp (line, "pc_del_age") == 0)
+          {
+              prefs_set_pc_del_age ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_del_age_val") == 0)
+          {
+              prefs_set_pc_del_age_val (atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_del_copied") == 0)
+          {
+              prefs_set_pc_del_copied ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_auto_fetch") == 0)
+          {
+              prefs_set_pc_auto_fetch ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_log") == 0)
+          {
+              prefs_set_pc_log ((gboolean)atoi(arg));
+          }
+	  else if(g_ascii_strcasecmp (line, "pc_log_file") == 0)
+	  {
+	      prefs_set_pc_log_file (arg);
+	  }
+          else if(g_ascii_strcasecmp (line, "pc_auto_sync") == 0)
+          {
+              prefs_set_pc_auto_sync ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_ipod_del_age") == 0)
+          {
+              prefs_set_pc_ipod_del_age ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_ipod_del_age_val") == 0)
+          {
+              prefs_set_pc_ipod_del_age_val (atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_ipod_del_played") == 0)
+          {
+              prefs_set_pc_ipod_del_played ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_ipod_inc_date") == 0)
+          {
+              prefs_set_pc_ipod_inc_date ((gboolean)atoi(arg));
+          }
+          else if(g_ascii_strcasecmp (line, "pc_change_genre") == 0)
+          {
+              prefs_set_pc_change_genre ((gboolean)atoi(arg));
+          }
+
 	  else
 	  {   /* All leftover options will be stored into the prefs
 		 setting hash (generic options -- should have had this
@@ -926,32 +1010,32 @@ void
 read_prefs_defaults(void)
 {
   gchar *cfgdir = NULL;
-  gchar filename[PATH_MAX+1];
+  gchar *filename;
   FILE *fp = NULL;
   gboolean have_prefs = FALSE;
 
   cfgdir = prefs_get_cfgdir ();
-  if (cfgdir)
+
+  filename = g_build_filename (cfgdir, "prefs", NULL);
+  if(g_file_test(filename, G_FILE_TEST_EXISTS))
   {
-      snprintf(filename, PATH_MAX, "%s/prefs", cfgdir);
-      filename[PATH_MAX] = 0;
-      if(g_file_test(filename, G_FILE_TEST_EXISTS))
+      if((fp = fopen(filename, "r")))
       {
-	  if((fp = fopen(filename, "r")))
-	  {
-	      read_prefs_from_file_desc(fp);
-	      fclose(fp);
-	      have_prefs = TRUE; /* read prefs */
-	  }
-	  else
-	  {
-	      gtkpod_warning(_("Unable to open config file '%s' for reading\n"), filename);
-	  }
+	  read_prefs_from_file_desc(fp);
+	  fclose(fp);
+	  have_prefs = TRUE; /* read prefs */
       }
+      else
+      {
+	  gtkpod_warning(_("Unable to open config file '%s' for reading\n"), filename);
+	  }
   }
+  g_free (filename);
+
   if (!have_prefs)
   {
-      snprintf (filename, PATH_MAX, "/etc/gtkpod/prefs");
+      filename = g_build_filename ("/etc", "gtkpod", "prefs", NULL);
+
       if (g_file_test (filename, G_FILE_TEST_EXISTS))
       {
 	  if((fp = fopen(filename, "r")))
@@ -961,8 +1045,9 @@ read_prefs_defaults(void)
 	      have_prefs = TRUE; /* read prefs */
 	  }
       }
+      g_free (filename);
   }
-  C_FREE (cfgdir);
+  g_free (cfgdir);
   /* set version of the prefs file to "current" if none was read */
   if (!have_prefs)   cfg->version = g_ascii_strtod (VERSION, NULL);
 
@@ -1054,7 +1139,12 @@ gboolean read_prefs (GtkWidget *gtkpod, int argc, char *argv[])
 	  exit(1);
       }
   }
-  menu = GTK_CHECK_MENU_ITEM (glade_xml_get_widget (main_window_xml, "offline_menu"));
+
+/* FIXME: PODCASTS: remove Podcast menu */
+/*   podcast_read_from_file(); */
+/*   podcast_file_read_from_file(); */
+
+  menu = GTK_CHECK_MENU_ITEM (gtkpod_xml_get_widget (main_window_xml, "offline_menu"));
   gtk_check_menu_item_set_active (menu, prefs_get_offline ());
   return result;
 }
@@ -1140,12 +1230,15 @@ write_prefs_to_file_desc(FILE *fp)
     fprintf(fp, "parsetags=%d\n", prefs_get_parsetags());
     fprintf(fp, "parsetags_overwrite=%d\n", prefs_get_parsetags_overwrite());
     fprintf(fp, "parsetags_template=%s\n",cfg->parsetags_template);
+    fprintf(fp, "coverart=%d\n", prefs_get_coverart());
+    fprintf(fp, "coverart_template=%s\n",cfg->coverart_template);
     fprintf(fp, _("# position of sliders (paned): playlists, above tracks,\n# between sort tabs, and in statusbar.\n"));
     for (i=0; i<PANED_NUM; ++i)
     {
 	fprintf(fp, "paned_pos_%d=%d\n", i, prefs_get_paned_pos (i));
     }
     fprintf(fp, "sort_tab_num=%d\n",prefs_get_sort_tab_num());
+    fprintf(fp, "group_compilations=%d\n",prefs_get_group_compilations());
     fprintf(fp, "last_prefs_page=%d\n",prefs_get_last_prefs_page());
     fprintf(fp, "offline=%d\n",prefs_get_offline());
     fprintf(fp, "extended_info=%d\n",prefs_get_write_extended_info());
@@ -1198,38 +1291,46 @@ write_prefs_to_file_desc(FILE *fp)
     fprintf (fp, "startup_messages=%d\n", cfg->startup_messages);
     fprintf (fp, "mserv_use=%d\n", cfg->mserv_use);
     fprintf (fp, "mserv_report_probs=%d\n", cfg->mserv_report_probs);
-    fprintf(fp, "mserv_username=%s\n", cfg->mserv_username);
+    fprintf(fp, "pc_dir=%s\n", cfg->pc_dir);
+    fprintf(fp, "pc_del_age=%d\n", cfg->pc_del_age);
+    fprintf(fp, "pc_del_age_val=%d\n", cfg->pc_del_age_val);
+    fprintf(fp, "pc_del_copied=%d\n", cfg->pc_del_copied);
+    fprintf(fp, "pc_auto_fetch=%d\n", cfg->pc_auto_fetch);
+    fprintf(fp, "pc_log=%d\n", cfg->pc_log);
+    fprintf(fp, "pc_log_file=%s\n", cfg->pc_log_file);
+    fprintf(fp, "pc_auto_sync=%d\n", cfg->pc_auto_sync);
+    fprintf(fp, "pc_ipod_del_age=%d\n", cfg->pc_ipod_del_age);
+    fprintf(fp, "pc_ipod_del_age_val=%d\n", cfg->pc_ipod_del_age_val);
+    fprintf(fp, "pc_ipod_del_played=%d\n", cfg->pc_ipod_del_played);
+    fprintf(fp, "pc_ipod_inc_date=%d\n", cfg->pc_ipod_inc_date);
+    fprintf(fp, "pc_change_genre=%d\n", cfg->pc_change_genre);
 /*     fprintf (fp, "unused_gboolean3=%d\n", cfg->unused_gboolean3); */
 }
 
+
 void
 write_prefs (void)
 {
-    gchar filename[PATH_MAX+1];
+    gchar *filename;
     gchar *cfgdir;
     FILE *fp = NULL;
 
     cfgdir = prefs_get_cfgdir ();
-    if(!cfgdir)
-      {
-	gtkpod_warning (_("Settings are not saved.\n"));
-      }
+
+    filename = g_build_filename (cfgdir, "prefs", NULL);
+    if((fp = fopen(filename, "w")))
+    {
+	write_prefs_to_file_desc(fp);
+	fclose(fp);
+    }
     else
-      {
-	snprintf(filename, PATH_MAX, "%s/prefs", cfgdir);
-	filename[PATH_MAX] = 0;
-	if((fp = fopen(filename, "w")))
-	  {
-	    write_prefs_to_file_desc(fp);
-	    fclose(fp);
-	  }
-	else
-	  {
-	    gtkpod_warning (_("Unable to open '%s' for writing\n"),
-			    filename);
-	  }
-      }
-    C_FREE (cfgdir);
+    {
+	gtkpod_warning (_("Unable to open '%s' for writing\n"),
+			filename);
+    }
+
+    g_free (filename);
+    g_free (cfgdir);
 }
 
 
@@ -1269,24 +1370,12 @@ void sortcfg_free(struct sortcfg *c)
 static gchar *
 get_dirname_of_filename(const gchar *file)
 {
-    gint len;
-    gchar *buf, *result = NULL;
-
     if (!file) return NULL;
 
     if (g_file_test(file, G_FILE_TEST_IS_DIR))
-	buf = g_strdup (file);
+	return g_strdup (file);
     else
-	buf = g_path_get_dirname (file);
-
-    len = strlen (buf);
-    if (len && (buf[len-1] == '/'))	result = buf;
-    else
-    {
-	result = g_strdup_printf ("%s/", buf);
-	g_free (buf);
-    }
-    return result;
+	return g_path_get_dirname (file);
 }
 
 
@@ -1319,9 +1408,7 @@ void prefs_set_ipod_mount(const gchar *mp)
     if(cfg->ipod_mount) g_free(cfg->ipod_mount);
     /* if new mount point starts with "~/", we replace it with the
        home directory */
-    if (strncmp ("~/", mp, 2) == 0)
-      cfg->ipod_mount = g_build_filename (g_get_home_dir (), mp+2, NULL);
-    else cfg->ipod_mount = g_strdup(mp);
+    cfg->ipod_mount = convert_filename (mp);
     /* need to notify the info thread of new mount point */
     space_set_ipod_mount (cfg->ipod_mount);
     gp_itdb_set_mountpoint (cfg->ipod_mount);
@@ -1504,7 +1591,10 @@ struct cfg *clone_prefs(void)
 	for (i=0; i<PATH_NUM; ++i)
 	    result->path[i] = g_strdup (cfg->path[i]);
 	result->parsetags_template = g_strdup(cfg->parsetags_template);
+	result->coverart_template = g_strdup(cfg->coverart_template);
 	result->mserv_username = g_strdup(cfg->mserv_username);
+	result->pc_dir = g_strdup(cfg->pc_dir);
+	result->pc_log_file = g_strdup(cfg->pc_log_file);
     }
     return(result);
 }
@@ -1624,25 +1714,24 @@ void prefs_set_tm_col_width (gint col, gint width)
 }
 
 
-/* Returns "$HOME/.gtkpod" or NULL if dir does not exist and cannot be
-   created. You must g_free the string after use */
+/* Returns "$HOME/.gtkpod" and tries to create it if it does not
+   exist. */
 gchar *prefs_get_cfgdir (void)
 {
   G_CONST_RETURN gchar *str;
   gchar *cfgdir=NULL;
 
   if((str = g_get_home_dir ()))
-    {
+  {
       cfgdir = g_build_filename (str, ".gtkpod", NULL);
       if(!g_file_test(cfgdir, G_FILE_TEST_IS_DIR))
-	{
-	  if(mkdir(cfgdir, 0755) == -1)
-	    {
+      {
+	  if(mkdir(cfgdir, 0777) == -1)
+	  {
 	      gtkpod_warning(_("Unable to 'mkdir %s'\n"), cfgdir);
-	      C_FREE (cfgdir); /*defined in misc.h*/
-	    }
-	}
-    }
+	  }
+      }
+  }
   return cfgdir;
 }
 
@@ -1829,6 +1918,29 @@ void prefs_set_parsetags_template (const gchar *tpl)
     }
 }
 
+void prefs_set_coverart(gboolean active)
+{
+  cfg->coverart = active;
+}
+
+gboolean prefs_get_coverart(void)
+{
+  return cfg->coverart;
+}
+
+const gchar *prefs_get_coverart_template (void)
+{
+    return cfg->coverart_template;
+}
+
+void prefs_set_coverart_template (const gchar *tpl)
+{
+    if (tpl)
+    {
+	g_free(cfg->coverart_template);
+	cfg->coverart_template = g_strdup (tpl);
+    }
+}
 
 /* Display column tm_item @visible: new value */
 void prefs_set_col_visible (TM_item tm_item, gboolean visible)
@@ -2014,6 +2126,17 @@ void prefs_set_sort_tab_num (gint i, gboolean update_display)
     }
 }
 
+gboolean prefs_get_group_compilations (void)
+{
+    return cfg->group_compilations;
+}
+
+void prefs_set_group_compilations (gboolean val, gboolean update_display)
+{
+    cfg->group_compilations = val;
+    if (update_display) st_show_visible ();
+}
+
 GtkToolbarStyle prefs_get_toolbar_style (void)
 {
     return cfg->toolbar_style;
@@ -2658,6 +2781,145 @@ void prefs_set_unused_gboolean3(gboolean val)
     cfg->unused_gboolean3 = val;
 }
 
+void prefs_set_pc_dir (const gchar *str)
+{
+    g_return_if_fail (str);
+
+    g_free (cfg->pc_dir);
+    cfg->pc_dir = convert_filename (str);
+}
+
+/* g_free() after use */
+gchar *prefs_get_pc_dir (void)
+{
+    return g_strdup (cfg->pc_dir);
+}
+
+void prefs_set_pc_del_age(gboolean val)
+{
+    cfg->pc_del_age = val;
+}
+
+gboolean prefs_get_pc_del_age(void)
+{
+    return cfg->pc_del_age;
+}
+
+void prefs_set_pc_del_age_val(gint val)
+{
+    cfg->pc_del_age_val = val;
+}
+
+gint prefs_get_pc_del_age_val(void)
+{
+    return cfg->pc_del_age_val;
+}
+
+void prefs_set_pc_del_copied(gboolean val)
+{
+    cfg->pc_del_copied = val;
+}
+
+gboolean prefs_get_pc_del_copied(void)
+{
+    return cfg->pc_del_copied;
+}
+
+void prefs_set_pc_auto_fetch(gboolean val)
+{
+    cfg->pc_auto_fetch = val;
+}
+
+gboolean prefs_get_pc_auto_fetch(void)
+{
+    return cfg->pc_auto_fetch;
+}
+
+void prefs_set_pc_log(gboolean val)
+{
+    cfg->pc_log = val;
+}
+
+gboolean prefs_get_pc_log(void)
+{
+    return cfg->pc_log;
+}
+
+void prefs_set_pc_log_file(const gchar *str)
+{
+    if (str)
+    {
+        g_free (cfg->pc_log_file);
+        cfg->pc_log_file = convert_filename (str);
+    }
+}
+
+/* g_free() after use */
+gchar *prefs_get_pc_log_file(void)
+{
+    return g_strdup (cfg->pc_log_file);
+}
+
+void prefs_set_pc_auto_sync(gboolean val)
+{
+    cfg->pc_auto_sync = val;
+}
+
+gboolean prefs_get_pc_auto_sync(void)
+{
+    return cfg->pc_auto_sync;
+}
+
+void prefs_set_pc_ipod_del_age(gboolean val)
+{
+    cfg->pc_ipod_del_age = val;
+}
+
+gboolean prefs_get_pc_ipod_del_age(void)
+{
+    return cfg->pc_ipod_del_age;
+}
+
+void prefs_set_pc_ipod_del_age_val(gint val)
+{
+    cfg->pc_ipod_del_age_val = val;
+}
+
+gint prefs_get_pc_ipod_del_age_val(void)
+{
+    return cfg->pc_ipod_del_age_val;
+}
+
+void prefs_set_pc_ipod_del_played(gboolean val)
+{
+    cfg->pc_ipod_del_played = val;
+}
+
+gboolean prefs_get_pc_ipod_del_played(void)
+{
+    return cfg->pc_ipod_del_played;
+}
+
+void prefs_set_pc_ipod_inc_date(gboolean val)
+{
+    cfg->pc_ipod_inc_date = val;
+}
+
+gboolean prefs_get_pc_ipod_inc_date(void)
+{
+    return cfg->pc_ipod_inc_date;
+}
+
+void prefs_set_pc_change_genre(gboolean val)
+{
+    cfg->pc_change_genre = val;
+}
+
+gboolean prefs_get_pc_change_genre(void)
+{
+    return cfg->pc_change_genre;
+}
+
 /* ------------------------------------------------------------
 
    Functions for generic preferences settings
