@@ -1,4 +1,4 @@
-/* Time-stamp: <2005-07-01 23:16:54 jcs>
+/* Time-stamp: <2005-12-10 22:46:54 jcs>
 |
 |  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
@@ -24,7 +24,7 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: prefs.h,v 1.97 2005/07/01 16:53:44 jcsjcs Exp $
+|  $Id: prefs.h,v 1.102 2005/12/10 17:04:29 jcsjcs Exp $
 */
 
 #ifndef __PREFS_H__
@@ -131,6 +131,8 @@ struct cfg
   gboolean parsetags;           /* Get tags by parsing filename? */
   gchar   *parsetags_template;  /* template for parsing tags */
   gboolean parsetags_overwrite; /* Overwrite tags already set? */
+  gboolean coverart;            /* Read coverart when adding files? */
+  gchar *coverart_template;     /* template for coverart filename   */
   gboolean autosettags[TM_NUM_TAGS_PREFS]; /* autoset empty tags to filename?*/
   gint paned_pos[PANED_NUM];    /* position of the GtkPaned elements */
 
@@ -147,6 +149,7 @@ struct cfg
   gboolean write_charset;       /* Use selected charset when writing track? */
   gboolean add_recursively;     /* Add directories recursively? */
   gint sort_tab_num;            /* number of sort tabs displayed */
+  gboolean group_compilations;  /* group compilations when browsing */
   guint32 statusbar_timeout;    /* timeout for statusbar messages */
   gint last_prefs_page;         /* last page selected in prefs window */
   gchar *path[PATH_NUM];    /* path for 'Play Now...' (see PathType) */
@@ -161,6 +164,20 @@ struct cfg
   gchar *mserv_username;        /* username for mserv? */
   gboolean unused_gboolean3;    /* unused */
   float version;                /* version of gtkpod writing the cfg file */
+
+  gchar *pc_dir;                /* directory to store podcasts */
+  gboolean pc_del_age;          /* whether to delete old podcasts */
+  gint pc_del_age_val;          /* how old a podcast must be to be deleted */
+  gboolean pc_del_copied;       /* whether to delete once copied to iPod */
+  gboolean pc_auto_fetch;       /* whether to fetch podcasts automatically */
+  gboolean pc_log;              /* whether to log podcast information */
+  gchar *pc_log_file;           /* where to log to */
+  gboolean pc_auto_sync;        /* whether to automatically sync podcasts */
+  gboolean pc_ipod_del_age;     /* whether to delete old podcasts from iPod */
+  gint pc_ipod_del_age_val;     /* how old a podcast must be to be deleted */
+  gboolean pc_ipod_del_played;  /* whether to delete played podcasts */
+  gboolean pc_ipod_inc_date;    /* whether to include date in iPod metadata */
+  gboolean pc_change_genre;     /* whether to change genres to 'Podcast' */
 };
 
 
@@ -214,6 +231,10 @@ void prefs_set_autosettags (gint category, gboolean autoset);
 gboolean prefs_get_autosettags (gint category);
 void prefs_set_parsetags_template (const gchar *tpl);
 const gchar *prefs_get_parsetags_template (void);
+void prefs_set_coverart (gboolean active);
+gboolean prefs_get_coverart(void);
+void prefs_set_coverart_template (const gchar *tpl);
+const gchar *prefs_get_coverart_template (void);
 void prefs_set_last_dir_browse (const gchar * dir);
 const gchar *prefs_get_last_dir_browse (void);
 void prefs_set_charset (gchar *charset);
@@ -298,6 +319,8 @@ gboolean prefs_get_case_sensitive (void);
 void prefs_set_case_sensitive (gboolean val);
 gint prefs_get_sort_tab_num (void);
 void prefs_set_sort_tab_num (gint i, gboolean update_display);
+gboolean prefs_get_group_compilations (void);
+void prefs_set_group_compilations (gboolean val, gboolean update_display);
 GtkToolbarStyle prefs_get_toolbar_style (void);
 void prefs_set_toolbar_style (GtkToolbarStyle i);
 gint prefs_get_last_prefs_page (void);
@@ -351,6 +374,34 @@ void prefs_set_mserv_username(const gchar *root);
 gboolean prefs_get_autoimport_commandline(void);
 void prefs_set_autoimport_commandline(gboolean val);
 
+/* Podcast preferences */
+void prefs_set_pc_dir(const gchar *str);
+gchar *prefs_get_pc_dir(void);
+void prefs_set_pc_del_age(gboolean val);
+gboolean prefs_get_pc_del_age(void);
+void prefs_set_pc_del_age_val(gint val);
+gint prefs_get_pc_del_age_val(void);
+void prefs_set_pc_del_copied(gboolean val);
+gboolean prefs_get_pc_del_copied(void);
+void prefs_set_pc_auto_fetch(gboolean val);
+gboolean prefs_get_pc_auto_fetch(void);
+void prefs_set_pc_log(gboolean val);
+gboolean prefs_get_pc_log(void);
+void prefs_set_pc_log_file(const gchar *str);
+gchar *prefs_get_pc_log_file(void);
+void prefs_set_pc_auto_sync(gboolean val);
+gboolean prefs_get_pc_auto_sync(void);
+void prefs_set_pc_ipod_del_age(gboolean val);
+gboolean prefs_get_pc_ipod_del_age(void);
+void prefs_set_pc_ipod_del_age_val(gint val);
+gint prefs_get_pc_ipod_del_age_val(void);
+void prefs_set_pc_ipod_del_played(gboolean val);
+gboolean prefs_get_pc_ipod_del_played(void);
+void prefs_set_pc_ipod_inc_date(gboolean val);
+gboolean prefs_get_pc_ipod_inc_date(void);
+void prefs_set_pc_change_genre(gboolean val);
+gboolean prefs_get_pc_change_genre(void);
+
 gboolean prefs_get_disable_sorting(void);
 
 void prefs_set_string_value (const gchar *key, const gchar *value);
