@@ -1,8 +1,9 @@
-/* Time-stamp: <2004-03-24 22:26:07 JST jcs>
+/* Time-stamp: <2005-06-17 22:12:11 jcs>
 |
-|  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
+|  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
 |  Part of the gtkpod project.
-|
+| 
+|  URL: http://www.gtkpod.org/
 |  URL: http://gtkpod.sourceforge.net/
 |
 |  This program is free software; you can redistribute it and/or modify
@@ -23,13 +24,13 @@
 |
 |  This product is not supported/written/published by Apple!
 |
-|  $Id: wavfile.h,v 1.4 2004/03/24 13:27:04 jcsjcs Exp $
+|  $Id: wavfile.h,v 1.6 2005/06/17 13:30:05 jcsjcs Exp $
 */
 
 #ifndef WAVFILEH_INCLUDED
 #define WAVFILEH_INCLUDED 1
 
-#include "track.h"
+#include "itdb.h"
 
 gboolean wav_write_file_info (gchar *filename, Track *track);
 Track *wav_get_file_info (gchar *name);
